"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Request(google.protobuf.message.Message):
    """=========================================================================================================
    CONTAINER
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELTAREQUEST_FIELD_NUMBER: builtins.int
    EXTENSIONMESSAGE_FIELD_NUMBER: builtins.int
    @property
    def deltaRequest(self) -> global___DataNoncePubkey: ...
    @property
    def extensionMessage(self) -> global___ExtensionMessage: ...
    def __init__(
        self,
        *,
        deltaRequest: global___DataNoncePubkey | None = ...,
        extensionMessage: global___ExtensionMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deltaRequest", b"deltaRequest", "extensionMessage", b"extensionMessage", "request", b"request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deltaRequest", b"deltaRequest", "extensionMessage", b"extensionMessage", "request", b"request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["request", b"request"]) -> typing_extensions.Literal["deltaRequest", "extensionMessage"] | None: ...

global___Request = Request

@typing_extensions.final
class ExtensionMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    name: builtins.str
    payload: builtins.bytes
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        payload: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "payload", b"payload"]) -> None: ...

global___ExtensionMessage = ExtensionMessage

@typing_extensions.final
class Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESSFULRESPONSE_FIELD_NUMBER: builtins.int
    UNSUCCESSFULRESPONSE_FIELD_NUMBER: builtins.int
    successfulResponse: builtins.bytes
    unsuccessfulResponse: builtins.str
    def __init__(
        self,
        *,
        successfulResponse: builtins.bytes = ...,
        unsuccessfulResponse: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["response", b"response", "successfulResponse", b"successfulResponse", "unsuccessfulResponse", b"unsuccessfulResponse"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["response", b"response", "successfulResponse", b"successfulResponse", "unsuccessfulResponse", b"unsuccessfulResponse"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["response", b"response"]) -> typing_extensions.Literal["successfulResponse", "unsuccessfulResponse"] | None: ...

global___Response = Response

@typing_extensions.final
class DataNoncePubkey(google.protobuf.message.Message):
    """=========================================================================================================
    ENCRYPTED MESSAGE FORMAT
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    PUBKEY_FIELD_NUMBER: builtins.int
    data: builtins.bytes
    nonce: builtins.bytes
    pubkey: builtins.bytes
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
        nonce: builtins.bytes = ...,
        pubkey: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "nonce", b"nonce", "pubkey", b"pubkey"]) -> None: ...

global___DataNoncePubkey = DataNoncePubkey

@typing_extensions.final
class DataNonce(google.protobuf.message.Message):
    """=========================================================================================================
    ENCRYPTED SEALED MESSAGED FORMAT
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    data: builtins.bytes
    nonce: builtins.bytes
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
        nonce: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "nonce", b"nonce"]) -> None: ...

global___DataNonce = DataNonce

@typing_extensions.final
class SealedEncryptedMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTEDMESSAGE_FIELD_NUMBER: builtins.int
    SEALINGKEYPARAMS_FIELD_NUMBER: builtins.int
    @property
    def encryptedMessage(self) -> global___DataNonce: ...
    sealingKeyParams: builtins.bytes
    def __init__(
        self,
        *,
        encryptedMessage: global___DataNonce | None = ...,
        sealingKeyParams: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryptedMessage", b"encryptedMessage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryptedMessage", b"encryptedMessage", "sealingKeyParams", b"sealingKeyParams"]) -> None: ...

global___SealedEncryptedMessage = SealedEncryptedMessage

@typing_extensions.final
class EncryptionHeader(google.protobuf.message.Message):
    """* LAYOUT
      Every stored file has the following layout: (EH || Enc(VH || CH || CB))
        EH = EncryptionHeader: specifies how the rest of the file is encrypted, including key ids.
        VH = VersionHeader: specifies a version number allowing for non-protobuf-supported changes in the rest of the layout.
        CH = ChunkHeader: specifies common integrity-checked values as well as format specification for the body.
        CB = ChunkBody(blob): the actual body of the file, including potential additional metadata header when needed.

    * VERSIONING
      Encrypted data is consumed only by enclaves, so we only need to be *read* compatible, but not *write*. Changes in
      the client-enclave protocol should be reflected in infrastructure versioning, e.g. if we change the result format.
      The following changes are anticipated:
        1. Protobuf-compatible encrypted format(CH || CB => CH' || CB') changes
             Ideally changes should conform to https://developers.google.com/protocol-buffers/docs/proto#updating. As
             long as we do this we don't need to write any special code or bump version numbers.
        2. Protobuf-incompatible encrypted format(CH || CB => X) changes
             If we change the data format completely (for example switch to FlatBuffer) then we still need to keep the
             VersionHeader definition as-is, bump the version number, and write version-specific code to handle the new
             data version, as well as potentially keep the old version's code around.

             For example, say the pre-bump code reading a file looks as follows:
               ...
               let version_header: VersionHeader = prost::Message::decode(&mut buffer)?;
               if version_header.version != 0 {
                 Err(format!("Cannot decode version {}", version_header.version))?;
               }
               let chunk_header: ChunkHeader = prost::Message::decode(&mut buffer)?;
               ...

             The post-bump code would then look as follows:
               ...
               let version_header: VersionHeader = prost::Message::decode(&mut buffer)?;
               match version_header.version {
                 0 => {
                   let chunk_header: ChunkHeader = prost::Message::decode(&mut buffer)?;
                   ... old code ...
                 }
                 1 => {
                   let fancy_fb_chunk: FbChunk = flatbuffers::decode(&mut buffer)?;
                   ... new code ...
                 }
                 _ => {
                   Err(format!("Cannot decode version {}", version_header.version))?;
                 }
               }
               ...

             Note that we don't need to write special code for *writing* (can write flatbuffers directly) because we only
             need read-compatibility.
        3. Encryption (EH => EH') changes
             If the encryption method itself changes (change of cipher, change of key identification), then ideally a new
             `oneof` variant should be added to `EncryptionHeader`, and should be handled accordingly in code when
             reading. Note that `EncryptionHeader` is plaintext, so we must make sure attackers cannot do "re-versioning"
             attacks triggering unintended codepaths. Authenticated encryption is designed to prevent this, so plaintext
             versioning may be used in this context. Change in encryption method may also be coupled with a complete
             restructuring of the encrypted data format (including `VersionHeader`). This is *only* possible if the
             encryption method actually changes.
             To illustrate why, say we introduced a new EH `oneof` variant that actually encodes the same encryption
             method as `EncryptionHeader::ChilyKey`, but changes the internal structuring of the encoded data. Now an
             attacker can create an encrypted data blob with the old format but specifying the new encryption variant.
             Because the encryption method is the same, the data blob will pass the authenticated (de)encryption phase,
             which means code handling the old format will be called with newly formatted data.

    Encryption header (unencrypted)
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHILYKEY_FIELD_NUMBER: builtins.int
    @property
    def chilyKey(self) -> global___ChilyKey: ...
    def __init__(
        self,
        *,
        chilyKey: global___ChilyKey | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chilyKey", b"chilyKey", "encryptionHeader", b"encryptionHeader"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chilyKey", b"chilyKey", "encryptionHeader", b"encryptionHeader"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["encryptionHeader", b"encryptionHeader"]) -> typing_extensions.Literal["chilyKey"] | None: ...

global___EncryptionHeader = EncryptionHeader

@typing_extensions.final
class ChilyKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTIONNONCE_FIELD_NUMBER: builtins.int
    encryptionNonce: builtins.bytes
    def __init__(
        self,
        *,
        encryptionNonce: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryptionNonce", b"encryptionNonce"]) -> None: ...

global___ChilyKey = ChilyKey

@typing_extensions.final
class VersionHeader(google.protobuf.message.Message):
    """Version header (encrypted)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.int
    def __init__(
        self,
        *,
        version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["version", b"version"]) -> None: ...

global___VersionHeader = VersionHeader

@typing_extensions.final
class ChunkHeader(google.protobuf.message.Message):
    """Data format header (encrypted)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTRAENTROPY_FIELD_NUMBER: builtins.int
    UNTRUSTEDCONTENTSIZE_FIELD_NUMBER: builtins.int
    UNTRUSTEDCHUNKCONTENTSIZES_FIELD_NUMBER: builtins.int
    extraEntropy: builtins.bytes
    """Additional entropy to ensure low-entropy content is not bruteforce-able."""
    untrustedContentSize: builtins.int
    """A field indicating the size of the underlying data. Currently this should only be set for manifest chunks where
    it indicates the size of the overall underlying dataset.
    WARNING: This field should be treated as a potential attack vector. Ideally a potential mismatch between this
    size and the actual size should be handled in common low-level code such as `ChunkReader`.
    """
    @property
    def untrustedChunkContentSizes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """A field indicating the size of the underlying chunks' contents, meant to speed up seeks. Should only be set for
        manifest chunks.
        WARNING: This field should be treated as a potential attack vector. Ideally a potential mismatch between these
        sizes and the actual chunk content sizes should be handled in common low-level code such as `ChunkReader`.
        """
    def __init__(
        self,
        *,
        extraEntropy: builtins.bytes = ...,
        untrustedContentSize: builtins.int | None = ...,
        untrustedChunkContentSizes: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_untrustedContentSize", b"_untrustedContentSize", "untrustedContentSize", b"untrustedContentSize"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_untrustedContentSize", b"_untrustedContentSize", "extraEntropy", b"extraEntropy", "untrustedChunkContentSizes", b"untrustedChunkContentSizes", "untrustedContentSize", b"untrustedContentSize"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_untrustedContentSize", b"_untrustedContentSize"]) -> typing_extensions.Literal["untrustedContentSize"] | None: ...

global___ChunkHeader = ChunkHeader



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure_blob_storage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61zure_blob_storage.proto\x12\x12\x61zure_blob_storage\"\x0c\n\nImportRole\":\n\nExportRole\x12,\n\x05input\x18\x01 \x01(\x0b\x32\x1d.azure_blob_storage.SinkInput\"\x1a\n\nSingleFile\x12\x0c\n\x04name\x18\x01 \x01(\t\"\t\n\x07RawFile\"L\n\x07ZipFile\x12\x34\n\nsingleFile\x18\x01 \x01(\x0b\x32\x1e.azure_blob_storage.SingleFileH\x00\x42\x0b\n\tselection\"\x8d\x01\n\tSinkInput\x12\x12\n\ndependency\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12*\n\x03raw\x18\x03 \x01(\x0b\x32\x1b.azure_blob_storage.RawFileH\x00\x12*\n\x03zip\x18\x04 \x01(\x0b\x32\x1b.azure_blob_storage.ZipFileH\x00\x42\x06\n\x04\x66ile\"\xb8\x01\n#AzureBlobStorageWorkerConfiguration\x12\x1d\n\x15\x63redentialsDependency\x18\x01 \x01(\t\x12\x34\n\nimportRole\x18\x02 \x01(\x0b\x32\x1e.azure_blob_storage.ImportRoleH\x00\x12\x34\n\nexportRole\x18\x03 \x01(\x0b\x32\x1e.azure_blob_storage.ExportRoleH\x00\x42\x06\n\x04roleb\x06proto3')



_IMPORTROLE = DESCRIPTOR.message_types_by_name['ImportRole']
_EXPORTROLE = DESCRIPTOR.message_types_by_name['ExportRole']
_SINGLEFILE = DESCRIPTOR.message_types_by_name['SingleFile']
_RAWFILE = DESCRIPTOR.message_types_by_name['RawFile']
_ZIPFILE = DESCRIPTOR.message_types_by_name['ZipFile']
_SINKINPUT = DESCRIPTOR.message_types_by_name['SinkInput']
_AZUREBLOBSTORAGEWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['AzureBlobStorageWorkerConfiguration']
ImportRole = _reflection.GeneratedProtocolMessageType('ImportRole', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTROLE,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.ImportRole)
  })
_sym_db.RegisterMessage(ImportRole)

ExportRole = _reflection.GeneratedProtocolMessageType('ExportRole', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTROLE,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.ExportRole)
  })
_sym_db.RegisterMessage(ExportRole)

SingleFile = _reflection.GeneratedProtocolMessageType('SingleFile', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEFILE,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.SingleFile)
  })
_sym_db.RegisterMessage(SingleFile)

RawFile = _reflection.GeneratedProtocolMessageType('RawFile', (_message.Message,), {
  'DESCRIPTOR' : _RAWFILE,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.RawFile)
  })
_sym_db.RegisterMessage(RawFile)

ZipFile = _reflection.GeneratedProtocolMessageType('ZipFile', (_message.Message,), {
  'DESCRIPTOR' : _ZIPFILE,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.ZipFile)
  })
_sym_db.RegisterMessage(ZipFile)

SinkInput = _reflection.GeneratedProtocolMessageType('SinkInput', (_message.Message,), {
  'DESCRIPTOR' : _SINKINPUT,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.SinkInput)
  })
_sym_db.RegisterMessage(SinkInput)

AzureBlobStorageWorkerConfiguration = _reflection.GeneratedProtocolMessageType('AzureBlobStorageWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _AZUREBLOBSTORAGEWORKERCONFIGURATION,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.AzureBlobStorageWorkerConfiguration)
  })
_sym_db.RegisterMessage(AzureBlobStorageWorkerConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMPORTROLE._serialized_start=48
  _IMPORTROLE._serialized_end=60
  _EXPORTROLE._serialized_start=62
  _EXPORTROLE._serialized_end=120
  _SINGLEFILE._serialized_start=122
  _SINGLEFILE._serialized_end=148
  _RAWFILE._serialized_start=150
  _RAWFILE._serialized_end=159
  _ZIPFILE._serialized_start=161
  _ZIPFILE._serialized_end=237
  _SINKINPUT._serialized_start=240
  _SINKINPUT._serialized_end=381
  _AZUREBLOBSTORAGEWORKERCONFIGURATION._serialized_start=384
  _AZUREBLOBSTORAGEWORKERCONFIGURATION._serialized_end=568
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: salesforce.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10salesforce.proto\x12\nsalesforce\"\x06\n\x04\x43ore\"\x10\n\x0eMarketingCloud\"s\n\nImportRole\x12 \n\x04\x63ore\x18\x01 \x01(\x0b\x32\x10.salesforce.CoreH\x00\x12\x34\n\x0emarketingCloud\x18\x02 \x01(\x0b\x32\x1a.salesforce.MarketingCloudH\x00\x42\r\n\x0bproductType\"2\n\nExportRole\x12$\n\x05input\x18\x01 \x01(\x0b\x32\x15.salesforce.SinkInput\"\x1a\n\nSingleFile\x12\x0c\n\x04name\x18\x01 \x01(\t\"\t\n\x07RawFile\"D\n\x07ZipFile\x12,\n\nsingleFile\x18\x01 \x01(\x0b\x32\x16.salesforce.SingleFileH\x00\x42\x0b\n\tselection\"}\n\tSinkInput\x12\x12\n\ndependency\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\"\n\x03raw\x18\x03 \x01(\x0b\x32\x13.salesforce.RawFileH\x00\x12\"\n\x03zip\x18\x04 \x01(\x0b\x32\x13.salesforce.ZipFileH\x00\x42\x06\n\x04\x66ile\"\xc6\x01\n\x1dSalesforceWorkerConfiguration\x12\x1d\n\x15\x63redentialsDependency\x18\x01 \x01(\t\x12,\n\nimportRole\x18\x02 \x01(\x0b\x32\x16.salesforce.ImportRoleH\x00\x12,\n\nexportRole\x18\x03 \x01(\x0b\x32\x16.salesforce.ExportRoleH\x00\x12\x11\n\tdomainUrl\x18\x04 \x01(\t\x12\x0f\n\x07\x61piName\x18\x05 \x01(\tB\x06\n\x04roleb\x06proto3')



_CORE = DESCRIPTOR.message_types_by_name['Core']
_MARKETINGCLOUD = DESCRIPTOR.message_types_by_name['MarketingCloud']
_IMPORTROLE = DESCRIPTOR.message_types_by_name['ImportRole']
_EXPORTROLE = DESCRIPTOR.message_types_by_name['ExportRole']
_SINGLEFILE = DESCRIPTOR.message_types_by_name['SingleFile']
_RAWFILE = DESCRIPTOR.message_types_by_name['RawFile']
_ZIPFILE = DESCRIPTOR.message_types_by_name['ZipFile']
_SINKINPUT = DESCRIPTOR.message_types_by_name['SinkInput']
_SALESFORCEWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['SalesforceWorkerConfiguration']
Core = _reflection.GeneratedProtocolMessageType('Core', (_message.Message,), {
  'DESCRIPTOR' : _CORE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.Core)
  })
_sym_db.RegisterMessage(Core)

MarketingCloud = _reflection.GeneratedProtocolMessageType('MarketingCloud', (_message.Message,), {
  'DESCRIPTOR' : _MARKETINGCLOUD,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.MarketingCloud)
  })
_sym_db.RegisterMessage(MarketingCloud)

ImportRole = _reflection.GeneratedProtocolMessageType('ImportRole', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTROLE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.ImportRole)
  })
_sym_db.RegisterMessage(ImportRole)

ExportRole = _reflection.GeneratedProtocolMessageType('ExportRole', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTROLE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.ExportRole)
  })
_sym_db.RegisterMessage(ExportRole)

SingleFile = _reflection.GeneratedProtocolMessageType('SingleFile', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEFILE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.SingleFile)
  })
_sym_db.RegisterMessage(SingleFile)

RawFile = _reflection.GeneratedProtocolMessageType('RawFile', (_message.Message,), {
  'DESCRIPTOR' : _RAWFILE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.RawFile)
  })
_sym_db.RegisterMessage(RawFile)

ZipFile = _reflection.GeneratedProtocolMessageType('ZipFile', (_message.Message,), {
  'DESCRIPTOR' : _ZIPFILE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.ZipFile)
  })
_sym_db.RegisterMessage(ZipFile)

SinkInput = _reflection.GeneratedProtocolMessageType('SinkInput', (_message.Message,), {
  'DESCRIPTOR' : _SINKINPUT,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.SinkInput)
  })
_sym_db.RegisterMessage(SinkInput)

SalesforceWorkerConfiguration = _reflection.GeneratedProtocolMessageType('SalesforceWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _SALESFORCEWORKERCONFIGURATION,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.SalesforceWorkerConfiguration)
  })
_sym_db.RegisterMessage(SalesforceWorkerConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CORE._serialized_start=32
  _CORE._serialized_end=38
  _MARKETINGCLOUD._serialized_start=40
  _MARKETINGCLOUD._serialized_end=56
  _IMPORTROLE._serialized_start=58
  _IMPORTROLE._serialized_end=173
  _EXPORTROLE._serialized_start=175
  _EXPORTROLE._serialized_end=225
  _SINGLEFILE._serialized_start=227
  _SINGLEFILE._serialized_end=253
  _RAWFILE._serialized_start=255
  _RAWFILE._serialized_end=264
  _ZIPFILE._serialized_start=266
  _ZIPFILE._serialized_end=334
  _SINKINPUT._serialized_start=336
  _SINKINPUT._serialized_end=461
  _SALESFORCEWORKERCONFIGURATION._serialized_start=464
  _SALESFORCEWORKERCONFIGURATION._serialized_end=662
# @@protoc_insertion_point(module_scope)



from .proto import EnclaveEndorsement, EnclaveEndorsements

from typing import Optional
from cryptography import x509
from cryptography.x509 import Certificate
from cryptography.x509.oid import NameOID
from cryptography.hazmat.primitives import hashes, serialization
from cryptography.hazmat.primitives.asymmetric import padding, rsa
import datetime

__all__ = ["Auth"]

PKey = rsa.RSAPrivateKey


class Auth:
    """
    This class wraps the certificate used to identify a user and implements the
    signing of the messages that are sent to the enclave
    """

    _endorsements: EnclaveEndorsements

    def __init__(
        self,
        certificate_chain: bytes,
        keypair: PKey,
        user_id: str,
    ):
        """
        Create an authentication object with the supplied certificate chain and
        keypair. To authenticate to the platform, you must create an auth object
        with `decentriq_platform.Client.create_auth`, retrieve the necessary endorsements
        e.g., with `decentriq_platform.Endorser.get_decentriq_pki_endorsement` and
        attach the endorsement to your auth object with
        `decentriq_platform.authentication.Auth.attach_endorsement`.
        """
        self.certificate_chain = certificate_chain
        self.kp = keypair
        self.user_id = user_id
        self._endorsements = EnclaveEndorsements()

    def _get_user_id(self) -> str:
        return self.user_id

    def _sign(self, data: bytes) -> bytes:
        return self.kp.sign(data, padding.PKCS1v15(), hashes.SHA512())

    def get_certificate_chain_pem(self) -> bytes:
        """
        Returns the chain of certificates in PEM format
        """
        return self.certificate_chain

    @property
    def endorsements(self) -> EnclaveEndorsements:
        return self._endorsements

    def attach_endorsement(
        self,
        /,
        decentriq_pki: Optional[EnclaveEndorsement] = None,
        personal_pki: Optional[EnclaveEndorsement] = None,
        dcr_secret: Optional[EnclaveEndorsement] = None,
    ):
        if decentriq_pki:
            self._endorsements.dqPki.CopyFrom(decentriq_pki)
        if personal_pki:
            self._endorsements.personalPki.CopyFrom(personal_pki)
        if dcr_secret:
            self._endorsements.dcrSecret.CopyFrom(dcr_secret)


class Sigma:
    def __init__(self, signature: bytes, mac_tag: bytes, auth_pki: Auth):
        self.signature: bytes = signature
        self.mac_tag: bytes = mac_tag
        self.auth_pki: Auth = auth_pki

    def get_mac_tag(self) -> bytes:
        return self.mac_tag

    def get_signature(self) -> bytes:
        return self.signature

    def get_cert_chain(self) -> bytes:
        return self.auth_pki.get_certificate_chain_pem()


def generate_key(bit_size: int = 4096) -> PKey:
    key = rsa.generate_private_key(
        public_exponent=65537,
        key_size=bit_size,
    )
    return key


def generate_self_signed_certificate(user_email: str, key: PKey) -> bytes:
    cert_builder = x509.CertificateBuilder()
    now = datetime.datetime.utcnow()
    cert: Certificate = (
        cert_builder.subject_name(
            x509.Name([x509.NameAttribute(NameOID.COMMON_NAME, user_email)])
        )
        .issuer_name(x509.Name([x509.NameAttribute(NameOID.COMMON_NAME, user_email)]))
        .serial_number(1)
        .not_valid_before(now - datetime.timedelta(days=1))
        .not_valid_after(now + datetime.timedelta(days=10))
        .add_extension(x509.BasicConstraints(ca=False, path_length=None), critical=True)
        .public_key(key.public_key())
        .add_extension(
            x509.KeyUsage(
                digital_signature=True,
                content_commitment=True,
                key_encipherment=True,
                data_encipherment=False,
                key_agreement=False,
                key_cert_sign=False,
                crl_sign=False,
                encipher_only=False,
                decipher_only=False,
            ),
            critical=True,
        )
        .sign(key, hashes.SHA512())
    )
    return cert.public_bytes(serialization.Encoding.PEM)


def generate_csr(user_email: str, key: PKey) -> bytes:
    csr_builder = x509.CertificateSigningRequestBuilder()
    csr = (
        csr_builder.subject_name(
            x509.Name([x509.NameAttribute(NameOID.COMMON_NAME, user_email)])
        )
        .add_extension(x509.BasicConstraints(ca=False, path_length=None), critical=True)
        .add_extension(
            x509.KeyUsage(
                digital_signature=True,
                content_commitment=True,
                key_encipherment=True,
                data_encipherment=False,
                key_agreement=False,
                key_cert_sign=False,
                crl_sign=False,
                encipher_only=False,
                decipher_only=False,
            ),
            critical=True,
        )
        .sign(key, hashes.SHA512())
    )
    return csr.public_bytes(serialization.Encoding.PEM)



from __future__ import annotations

import base64
import functools
from enum import Enum
from typing import Dict, List, Optional
from typing_extensions import Self
import uuid
from ..attestation import enclave_specifications
from ..session import (
    LATEST_WORKER_PROTOCOL_VERSION,
)
from ..proto.length_delimited import serialize_length_delimited
from .version import DATA_SCIENCE_DCR_SUPPORTED_VERSION
from .node_definitions import NodeDefinition
from .analytics_dcr import AnalyticsDcrDefinition


__all__ = [
    "AnalyticsDcrBuilder",
]


class AnalyticsDcrType(str, Enum):
    STATIC = "STATIC"
    INTERACTIVE = "INTERACTIVE"


class ParticipantPermission(Enum):
    DATA_OWNER = 1
    ANALYST = 2


def _get_hl_specs(enclave_specs: Dict[str, EnclaveSpecification]):
    specs = [
        {
            "attestationProtoBase64": base64.b64encode(
                serialize_length_delimited(spec["proto"])
            ).decode(),
            "id": name,
            "workerProtocol": spec.get(
                "workerProtocol", LATEST_WORKER_PROTOCOL_VERSION
            ),
        }
        for name, spec in enclave_specs.items()
    ]
    return specs


class AnalyticsDcrBuilder:
    """
    A builder for constructing Analytics Data Clean Rooms.
    """

    def __init__(
        self,
        *,
        client: Client,
        enclave_specs: Optional[Dict[str, EnclaveSpecification]] = None,
    ) -> None:
        """
        Initialise an Analytics DCR builder.

        **Parameters**:
        - `client`: A `Client` object that can be used to retrieve information about the platform.
        - `enclave_specs`: Determines the types of enclaves that will supported by this Data Clean Room.
            If not specified, the latest enclave specifications known to this
            SDK version will be used.
        """
        self.client = client
        self.enclave_specs = (
            enclave_specs if enclave_specs else enclave_specifications.latest()
        )
        self.name = None
        self.description = ""
        self.owner = None
        self.dcr_id = None
        self.enable_development = False
        self.enable_airlock = False
        self.enable_auto_merge_feature = False
        self.compile_context = None
        self.node_definitions = []
        """The current list of Node Definitions that will be added to the Data Clean Room."""
        self.permissions = []
        """The list of permissions that will be added to the Data Clean Room."""

    def with_name(self, name: str) -> Self:
        """
        Set the name of the Data Clean Room.

        **Parameters**:
        - `name`: Name to be used for the Data Clean Room.
        """
        self.name = name
        return self

    def with_description(self, description: str) -> Self:
        """
        Set the description of the Data Clean Room.

        **Parameters**:
        - `description`: Description of the Data Clean Room.
        """
        self.description = description
        return self

    def add_participant(
        self,
        email: str,
        *,
        analyst_of: List[str] = [],
        data_owner_of: List[str] = [],
    ) -> Self:
        """
        Add a participant to the DCR being built.

        If the participant isn't assigned a role, the user can still view the
        DCR but cannot interact with it.

        **Parameters**:
        - `email`: The email address of the participant.
        - `analyst_of`: The names of the Compute Nodes that the user can run.
        - `data_owner_of`: The names of the Data Nodes to which the user can
          connect a dataset.
        """
        anaylst_permissions = [{"analyst": {"nodeId": node}} for node in analyst_of]
        data_owner_permissions = [
            {"dataOwner": {"nodeId": node}} for node in data_owner_of
        ]
        self.permissions.append(
            {"user": email, "permissions": anaylst_permissions + data_owner_permissions}
        )
        return self

    def with_auto_merge(self) -> Self:
        """
        Allow auto-merging of commits.
        This allows non-conflicting changes to be merged without rebasing.
        """
        self.enable_auto_merge_feature = True
        return self

    def with_owner(self, email: str) -> Self:
        """
        Set the owner of the Data Clean Room.

        **Parameters**:
        - `email`: The email address of the owner of the Data Clean Room.
        """
        self.owner = email
        return self

    def with_development_mode(self) -> Self:
        """
        Enable Development Mode in the Data Clean Room.

        This allows Development Computations to be executed in the Data Clean Room.
        Development Computations are not yet part of the Data Clean Room, but allow users
        to run new computations on top of existing DCRs.
        The driver enclave makes sure that only data to which the user already has access
        can be read.
        """
        self.enable_development = True
        return self

    def with_airlock(self) -> Self:
        """
        Enable the Airlock feature in the Data Clean Room.

        This requires Development Mode to be enabled.
        The Airlock feature allows the addition of Preview Nodes that allow
        restricting the amount of data that can be read from specific Data Nodes.
        """
        self.enable_airlock = True
        return self

    def add_node_definition(self, definition: NodeDefinition) -> Self:
        """
        Add a single node definition to this builder.

        A node definition defines how a Compute or Data Node
        should be constructed.
        """
        self.add_node_definitions([definition])
        return self

    def add_node_definitions(self, definitions: List[NodeDefinition]) -> Self:
        """
        Add a list of node definitions to this builder.

        Each node definition defines how the respective Compute or Data Node
        should be constructed.
        """
        self.node_definitions.extend(definitions)
        return self

    def build(self) -> AnalyticsDcrDefinition:
        """
        Build the Data Clean Room.

        In order to use the DCR, the output of this method should be passed to
        `client.publish_analytics_dcr`.
        """
        if not self.owner:
            raise Exception("The Data Room owner must be specified")
        if not self.name:
            raise Exception("The Data Room name must be specified")

        nodes = [
            node._get_high_level_representation() for node in self.node_definitions
        ]
        required_workers = functools.reduce(
            lambda a, b: a.union(b),
            [set(node.required_workers) for node in self.node_definitions],
            {"decentriq.driver"},
        )
        used_enclave_specs = {}
        for worker in required_workers:
            if worker in self.enclave_specs:
                used_enclave_specs[worker] = self.enclave_specs[worker]
            else:
                raise Exception(
                    f"One of the nodes you added requires a worker of type '{worker}',"
                    " but no enclave specification matching this worker is known to this builder."
                )
        used_hl_enclave_specs = _get_hl_specs(used_enclave_specs)
        permissions = self._add_owner_permissions()
        hl_dcr = {
            DATA_SCIENCE_DCR_SUPPORTED_VERSION: {
                # Only interactive DCRs are supported.
                "interactive": {
                    "commits": [],
                    "enableAutomergeFeature": self.enable_auto_merge_feature,
                    "initialConfiguration": {
                        "description": self.description,
                        "enableAirlock": self.enable_airlock,
                        "enableAllowEmptyFilesInValidation": False,
                        "enableDevelopment": self.enable_development,
                        "enablePostWorker": False,
                        "enableSafePythonWorkerStacktrace": True,
                        "enableServersideWasmValidation": True,
                        "enableSqliteWorker": False,
                        "enableTestDatasets": False,
                        "enclaveRootCertificatePem": self.client.decentriq_ca_root_certificate.decode(),
                        "enclaveSpecifications": used_hl_enclave_specs,
                        "id": self._generate_id(),
                        "nodes": nodes,
                        "participants": permissions,
                        "title": self.name,
                    },
                }
            }
        }
        return AnalyticsDcrDefinition(name=self.name, high_level=hl_dcr)

    def _add_owner_permissions(self):
        for entry in self.permissions:
            if entry["user"] == self.owner:
                permissions = entry["permissions"]
                permissions.append({"manager": {}})
                entry["permissions"] = permissions
                return self.permissions

        # Entry wasn't found for existing user, so add a new one.
        self.permissions.append({"user": self.owner, "permissions": [{"manager": {}}]})
        return self.permissions

    @staticmethod
    def _generate_id():
        return str(uuid.uuid4())



from google.protobuf.json_format import MessageToDict
from ...proto import (
    serialize_length_delimited,
    ComputeNodeFormat,
    parse_length_delimited,
)
from ..node import Node
from .proto import (
    GoogleDv360SinkWorkerConfiguration,
    SinkInput,
)


__docformat__ = "restructuredtext"
__pdoc__ = {
    "proto": False,
}


class GoogleDv360Sink(Node):
    """
    Compute node that creates a custom audience on Google DV360.
    """

    def __init__(
        self,
        name: str,
        input: SinkInput,
        credentialsDependency: str,
        advertiserId: str,
        displayName: str,
        description: str,
        membershipDurationDays: str,
    ) -> None:
        config = GoogleDv360SinkWorkerConfiguration(
            input=input,
            credentialsDependency=credentialsDependency,
            advertiserId=advertiserId,
            displayName=displayName,
            description=description,
            membershipDurationDays=membershipDurationDays,
        )
        config_serialized = serialize_length_delimited(config)
        dependencies = [input.dependency, credentialsDependency]
        super().__init__(
            name,
            config=config_serialized,
            enclave_type="decentriq.google-dv-360-sink-worker",
            dependencies=dependencies,
            output_format=ComputeNodeFormat.RAW,
        )


class GoogleDv360SinkWorkerDecoder:
    def decode(self, config: bytes):
        config_decoded = GoogleDv360SinkWorkerConfiguration()
        parse_length_delimited(config, config_decoded)
        return MessageToDict(config_decoded)


__all__ = [
    "GoogleDv360Sink",
]



import base64
import uuid
from ..client import Client
from typing import Optional, List
from decentriq_dcr_compiler import compiler
from ..types import MatchingId
from ..keychain import Keychain
from .lookalike_media import LookalikeMediaDcr, ExistingLookalikeMediaDcr
from ..proto import serialize_length_delimited
import json
from ..helpers import (
    create_session_from_driver_spec,
    get_latest_enclave_specs_as_dictionary,
)
from ..types import MATCHING_ID_INTERNAL_LOOKUP


def _generate_id():
    return str(uuid.uuid4())


class LookalikeMediaDcrBuilder:
    """
    A helper class to build a Lookalike Media DCR
    """

    def __init__(
        self,
        client: Client,
    ) -> None:
        self.client = client
        self.name = None
        self.main_publisher_email = None
        self.publisher_emails = []
        self.main_advertiser_email = None
        self.advertiser_emails = []
        self.matching_id = None
        self.audit_log_retrieval = True
        self.dev_computations = True
        self.agency_emails = []
        self.observer_emails = []
        self.existing = False

    def with_name(self, name: str):
        """
        Set the name of the Lookalike Media DCR.
        This is required when creating **new** Lookalike Media DCRs only.
        When creating from an existing DCR, the existing name will be used.

        **Parameters**:
        - `name`: Name to be used for the Lookalike Media DCR.
        """
        self.name = name

    def with_publisher_emails(self, main: str, additional: Optional[List[str]] = None):
        """
        Set the publisher email addresses.

        **Parameters**:
        - `main`: The main publisher email address.
        - `additional`: Optional list of additional publisher email addresses.
        """
        self.main_publisher_email = main
        if additional is not None:
            self.publisher_emails = additional

    def with_advertiser_emails(self, main: str, additional: Optional[List[str]] = None):
        """
        Set the advertiser email addresses.

        **Parameters**:
        - `main`: The main advertiser email address.
        - `additional`: Optional list of additional advertiser email addresses.
        """
        self.main_advertiser_email = main
        if additional is not None:
            self.advertiser_emails = additional

    def with_agency_emails(self, emails: List[str]):
        """
        Set the agency email addresses.

        **Parameters**:
        - `emails`: List of agency email addresses.
        """
        self.agency_emails = emails

    def with_observer_emails(self, emails: List[str]):
        """
        Set the observer email addresses.

        **Parameters**:
        - `emails`: List of observer email addresses.
        """
        self.observer_emails = emails

    def with_matching_id_format(self, matching_id: MatchingId):
        """
        Set the matching ID format.
        This is required when creating **new** Lookalike Media DCRs only.
        When creating from an existing DCR, the existing matching ID will be used.

        **Parameters**:
        - `matching_id`: The type of matching ID to use.
        """
        self.matching_id = matching_id

    def from_existing(self, lmdcr_id: str, keychain: Keychain):
        """
        Construct a new Lookalike Media DCR from an existing Lookalike Media DCR with the given ID.

        **Parameters**:
        - `lmdcr_id`: The ID of the existing Lookalike Media DCR.
        - `keychain`: The keychain to use to provision datasets from the old Lookalike Media DCR to the new Lookalike Media DCR.
        """
        self.existing = True
        self.lmdcr_id = lmdcr_id
        self.keychain = keychain

    def build_and_publish(self) -> LookalikeMediaDcr:
        """
        Build and publish the Lookalike Media DCR.
        """
        self._check_required_fields_provided()

        if self.existing:
            # Get existing LMDCR (high level from the enclave).
            driver_attestation_hash = self.client._get_lmdcr_driver_attestation_hash(
                self.lmdcr_id
            )
            driver_enclave_spec = self.client._get_enclave_spec_from_hash(
                driver_attestation_hash
            )
            if driver_enclave_spec == None:
                raise Exception(
                    f"Failed to find driver for data room {driver_enclave_spec}"
                )
            session = create_session_from_driver_spec(self.client, driver_enclave_spec)
            existing_lmdcr = session.retrieve_data_room(self.lmdcr_id)
            high_level_representation = json.loads(
                existing_lmdcr.highLevelRepresentation.decode()
            )
            existing = ExistingLookalikeMediaDcr(self.lmdcr_id, driver_enclave_spec)
            return LookalikeMediaDcr(self.client, high_level_representation, existing)
        else:
            id = f"Lookalike DCR {_generate_id()}"
            root_cert_pem = self.client.decentriq_ca_root_certificate.decode()
            (driver_spec, python_spec) = self._get_lmdcr_enclave_specs(self.client)
            (
                matching_id_format,
                matching_id_hashing_algorithm,
            ) = MATCHING_ID_INTERNAL_LOOKUP[self.matching_id]
            # The publisher and advertiser email lists need to contain all emails including the main one.
            publisher_emails = [self.main_publisher_email] + self.publisher_emails
            advertiser_emails = [self.main_advertiser_email] + self.advertiser_emails
            lmdcr = {
                "v3": {
                    "v3": {
                        "id": id,
                        "name": self.name,
                        "mainPublisherEmail": self.main_publisher_email,
                        "mainAdvertiserEmail": self.main_advertiser_email,
                        "matchingIdFormat": matching_id_format,
                        "hashMatchingIdWith": matching_id_hashing_algorithm,
                        "authenticationRootCertificatePem": root_cert_pem,
                        "driverEnclaveSpecification": {
                            "attestationProtoBase64": driver_spec.attestationProtoBase64,
                            "id": driver_spec.id,
                            "workerProtocol": driver_spec.workerProtocol,
                        },
                        "pythonEnclaveSpecification": {
                            "attestationProtoBase64": python_spec.attestationProtoBase64,
                            "id": python_spec.id,
                            "workerProtocol": python_spec.workerProtocol,
                        },
                        "enableAuditLogRetrieval": self.audit_log_retrieval,
                        "enableDevComputations": self.dev_computations,
                        "enableDebugMode": False,
                        "advertiserEmails": advertiser_emails,
                        "agencyEmails": self.agency_emails,
                        "observerEmails": self.observer_emails,
                        "publisherEmails": publisher_emails,
                    }
                }
            }
            return LookalikeMediaDcr(self.client, lmdcr)

    # Check all necessary options have been provided.
    def _check_required_fields_provided(self):
        # Only perform check when creating new LMDCRs.
        # If creating from existing, these options will be copied across from the existing LMDCR.
        if not self.from_existing:
            if self.name is None:
                raise Exception("A name must be provided")
            elif self.matching_id is None:
                raise Exception("A matching ID must be provided")
            elif self.main_publisher_email is None:
                raise Exception("A publisher email address must be provided")

    @staticmethod
    def _get_lmdcr_enclave_specs(
        client: Client,
    ) -> (compiler.EnclaveSpecification, compiler.EnclaveSpecification):
        enclave_specs = get_latest_enclave_specs_as_dictionary(client)
        driver_spec = {}
        python_spec = {}
        for spec_id, spec in enclave_specs.items():
            spec_payload = {
                "attestationProtoBase64": base64.b64encode(
                    serialize_length_delimited(spec["proto"])
                ).decode(),
                "id": spec_id,
                "workerProtocol": spec["workerProtocols"][0],
            }
            if "decentriq.driver" in spec_id:
                driver_spec = compiler.EnclaveSpecification.parse_obj(spec_payload)
            elif "decentriq.python-ml-worker" in spec_id:
                python_spec = compiler.EnclaveSpecification.parse_obj(spec_payload)
        return (driver_spec, python_spec)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import data_room_pb2 as data__room__pb2
from . import identity_endorsement_pb2 as identity__endorsement__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tgcg.proto\x12\x03gcg\x1a\x0f\x64\x61ta_room.proto\x1a\x1aidentity_endorsement.proto\"\x82\x0e\n\nGcgRequest\x12\x1f\n\x08userAuth\x18\x01 \x01(\x0b\x32\r.gcg.UserAuth\x12;\n\x15\x63reateDataRoomRequest\x18\x02 \x01(\x0b\x32\x1a.gcg.CreateDataRoomRequestH\x00\x12?\n\x17retrieveDataRoomRequest\x18\x03 \x01(\x0b\x32\x1c.gcg.RetrieveDataRoomRequestH\x00\x12g\n+retrieveCurrentDataRoomConfigurationRequest\x18\x04 \x01(\x0b\x32\x30.gcg.RetrieveCurrentDataRoomConfigurationRequestH\x00\x12K\n\x1dretrieveDataRoomStatusRequest\x18\x05 \x01(\x0b\x32\".gcg.RetrieveDataRoomStatusRequestH\x00\x12G\n\x1bupdateDataRoomStatusRequest\x18\x06 \x01(\x0b\x32 .gcg.UpdateDataRoomStatusRequestH\x00\x12?\n\x17retrieveAuditLogRequest\x18\x07 \x01(\x0b\x32\x1c.gcg.RetrieveAuditLogRequestH\x00\x12O\n\x1fpublishDatasetToDataRoomRequest\x18\x08 \x01(\x0b\x32$.gcg.PublishDatasetToDataRoomRequestH\x00\x12Q\n retrievePublishedDatasetsRequest\x18\t \x01(\x0b\x32%.gcg.RetrievePublishedDatasetsRequestH\x00\x12K\n\x1dremovePublishedDatasetRequest\x18\n \x01(\x0b\x32\".gcg.RemovePublishedDatasetRequestH\x00\x12;\n\x15\x65xecuteComputeRequest\x18\x0b \x01(\x0b\x32\x1a.gcg.ExecuteComputeRequestH\x00\x12\x31\n\x10jobStatusRequest\x18\x0c \x01(\x0b\x32\x15.gcg.JobStatusRequestH\x00\x12\x33\n\x11getResultsRequest\x18\r \x01(\x0b\x32\x16.gcg.GetResultsRequestH\x00\x12Q\n createConfigurationCommitRequest\x18\x0e \x01(\x0b\x32%.gcg.CreateConfigurationCommitRequestH\x00\x12U\n\"retrieveConfigurationCommitRequest\x18\x0f \x01(\x0b\x32\'.gcg.RetrieveConfigurationCommitRequestH\x00\x12Q\n executeDevelopmentComputeRequest\x18\x10 \x01(\x0b\x32%.gcg.ExecuteDevelopmentComputeRequestH\x00\x12[\n%generateMergeApprovalSignatureRequest\x18\x11 \x01(\x0b\x32*.gcg.GenerateMergeApprovalSignatureRequestH\x00\x12O\n\x1fmergeConfigurationCommitRequest\x18\x12 \x01(\x0b\x32$.gcg.MergeConfigurationCommitRequestH\x00\x12g\n+retrieveConfigurationCommitApproversRequest\x18\x13 \x01(\x0b\x32\x30.gcg.RetrieveConfigurationCommitApproversRequestH\x00\x12\x41\n\x18\x63\x61sAuxiliaryStateRequest\x18\x14 \x01(\x0b\x32\x1d.gcg.CasAuxiliaryStateRequestH\x00\x12\x43\n\x19readAuxiliaryStateRequest\x18\x15 \x01(\x0b\x32\x1e.gcg.ReadAuxiliaryStateRequestH\x00\x12O\n\x1fretrieveUsedAirlockQuotaRequest\x18\x16 \x01(\x0b\x32$.gcg.RetrieveUsedAirlockQuotaRequestH\x00\x12;\n\x15getResultsSizeRequest\x18\x17 \x01(\x0b\x32\x1a.gcg.GetResultsSizeRequestH\x00\x12\x46\n\x12\x65ndorsementRequest\x18\x65 \x01(\x0b\x32(.identity_endorsement.EndorsementRequestH\x00\x42\r\n\x0bgcg_request\"\x9c\x0e\n\x0bGcgResponse\x12\x11\n\x07\x66\x61ilure\x18\x01 \x01(\tH\x00\x12=\n\x16\x63reateDataRoomResponse\x18\x02 \x01(\x0b\x32\x1b.gcg.CreateDataRoomResponseH\x00\x12\x41\n\x18retrieveDataRoomResponse\x18\x03 \x01(\x0b\x32\x1d.gcg.RetrieveDataRoomResponseH\x00\x12i\n,retrieveCurrentDataRoomConfigurationResponse\x18\x04 \x01(\x0b\x32\x31.gcg.RetrieveCurrentDataRoomConfigurationResponseH\x00\x12M\n\x1eretrieveDataRoomStatusResponse\x18\x05 \x01(\x0b\x32#.gcg.RetrieveDataRoomStatusResponseH\x00\x12I\n\x1cupdateDataRoomStatusResponse\x18\x06 \x01(\x0b\x32!.gcg.UpdateDataRoomStatusResponseH\x00\x12\x41\n\x18retrieveAuditLogResponse\x18\x07 \x01(\x0b\x32\x1d.gcg.RetrieveAuditLogResponseH\x00\x12Q\n publishDatasetToDataRoomResponse\x18\x08 \x01(\x0b\x32%.gcg.PublishDatasetToDataRoomResponseH\x00\x12S\n!retrievePublishedDatasetsResponse\x18\t \x01(\x0b\x32&.gcg.RetrievePublishedDatasetsResponseH\x00\x12M\n\x1eremovePublishedDatasetResponse\x18\n \x01(\x0b\x32#.gcg.RemovePublishedDatasetResponseH\x00\x12=\n\x16\x65xecuteComputeResponse\x18\x0b \x01(\x0b\x32\x1b.gcg.ExecuteComputeResponseH\x00\x12\x33\n\x11jobStatusResponse\x18\x0c \x01(\x0b\x32\x16.gcg.JobStatusResponseH\x00\x12?\n\x17getResultsResponseChunk\x18\r \x01(\x0b\x32\x1c.gcg.GetResultsResponseChunkH\x00\x12\x41\n\x18getResultsResponseFooter\x18\x0e \x01(\x0b\x32\x1d.gcg.GetResultsResponseFooterH\x00\x12S\n!createConfigurationCommitResponse\x18\x0f \x01(\x0b\x32&.gcg.CreateConfigurationCommitResponseH\x00\x12W\n#retrieveConfigurationCommitResponse\x18\x10 \x01(\x0b\x32(.gcg.RetrieveConfigurationCommitResponseH\x00\x12]\n&generateMergeApprovalSignatureResponse\x18\x11 \x01(\x0b\x32+.gcg.GenerateMergeApprovalSignatureResponseH\x00\x12Q\n mergeConfigurationCommitResponse\x18\x12 \x01(\x0b\x32%.gcg.MergeConfigurationCommitResponseH\x00\x12i\n,retrieveConfigurationCommitApproversResponse\x18\x13 \x01(\x0b\x32\x31.gcg.RetrieveConfigurationCommitApproversResponseH\x00\x12\x43\n\x19\x63\x61sAuxiliaryStateResponse\x18\x14 \x01(\x0b\x32\x1e.gcg.CasAuxiliaryStateResponseH\x00\x12\x45\n\x1areadAuxiliaryStateResponse\x18\x15 \x01(\x0b\x32\x1f.gcg.ReadAuxiliaryStateResponseH\x00\x12Q\n retrieveUsedAirlockQuotaResponse\x18\x16 \x01(\x0b\x32%.gcg.RetrieveUsedAirlockQuotaResponseH\x00\x12=\n\x16getResultsSizeResponse\x18\x17 \x01(\x0b\x32\x1b.gcg.GetResultsSizeResponseH\x00\x12H\n\x13\x65ndorsementResponse\x18\x65 \x01(\x0b\x32).identity_endorsement.EndorsementResponseH\x00\x42\x0e\n\x0cgcg_response\"i\n\x08UserAuth\x12\x15\n\x03pki\x18\x01 \x01(\x0b\x32\x08.gcg.Pki\x12\x46\n\x13\x65nclaveEndorsements\x18\x02 \x01(\x0b\x32).identity_endorsement.EnclaveEndorsements\"=\n\x03Pki\x12\x14\n\x0c\x63\x65rtChainPem\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\r\n\x05idMac\x18\x03 \x01(\x0c\"\xb4\x01\n\x15\x43reateDataRoomRequest\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\x12$\n\x17highLevelRepresentation\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x12\x1d\n\x10\x64\x61taRoomMetadata\x18\x03 \x01(\x0cH\x01\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentationB\x13\n\x11_dataRoomMetadata\"\x8c\x01\n\x16\x43reateDataRoomResponse\x12\x14\n\ndataRoomId\x18\x01 \x01(\x0cH\x00\x12?\n\x17\x64\x61taRoomValidationError\x18\x02 \x01(\x0b\x32\x1c.gcg.DataRoomValidationErrorH\x00\x42\x1b\n\x19\x63reate_data_room_response\"\xc6\x02\n\x17\x44\x61taRoomValidationError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x1c\n\x0fpermissionIndex\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x1a\n\rcomputeNodeId\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1d\n\x10userPermissionId\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\'\n\x1a\x61ttestationSpecificationId\x18\x05 \x01(\tH\x03\x88\x01\x01\x12#\n\x16\x61uthenticationMethodId\x18\x06 \x01(\tH\x04\x88\x01\x01\x42\x12\n\x10_permissionIndexB\x10\n\x0e_computeNodeIdB\x13\n\x11_userPermissionIdB\x1d\n\x1b_attestationSpecificationIdB\x19\n\x17_authenticationMethodId\"\x80\x01\n\x1fPublishDatasetToDataRoomRequest\x12\x13\n\x0b\x64\x61tasetHash\x18\x01 \x01(\x0c\x12\x12\n\ndataRoomId\x18\x02 \x01(\x0c\x12\x0e\n\x06leafId\x18\x03 \x01(\t\x12\x15\n\rencryptionKey\x18\x04 \x01(\x0c\x12\r\n\x05scope\x18\x05 \x01(\x0c\"\"\n PublishDatasetToDataRoomResponse\"\xe2\x02\n\x15\x45xecuteComputeRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63omputeNodeIds\x18\x02 \x03(\t\x12\x10\n\x08isDryRun\x18\x03 \x01(\x08\x12\r\n\x05scope\x18\x04 \x01(\x0c\x12>\n\nparameters\x18\x05 \x03(\x0b\x32*.gcg.ExecuteComputeRequest.ParametersEntry\x12\x42\n\x0ctestDatasets\x18\x06 \x03(\x0b\x32,.gcg.ExecuteComputeRequest.TestDatasetsEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x45\n\x11TestDatasetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.gcg.TestDataset:\x02\x38\x01\"\x8e\x03\n ExecuteDevelopmentComputeRequest\x12\x1d\n\x15\x63onfigurationCommitId\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63omputeNodeIds\x18\x02 \x03(\t\x12\x10\n\x08isDryRun\x18\x03 \x01(\x08\x12\r\n\x05scope\x18\x04 \x01(\x0c\x12I\n\nparameters\x18\x05 \x03(\x0b\x32\x35.gcg.ExecuteDevelopmentComputeRequest.ParametersEntry\x12M\n\x0ctestDatasets\x18\x06 \x03(\x0b\x32\x37.gcg.ExecuteDevelopmentComputeRequest.TestDatasetsEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x45\n\x11TestDatasetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.gcg.TestDataset:\x02\x38\x01\":\n\x0bTestDataset\x12\x15\n\rencryptionKey\x18\x01 \x01(\x0c\x12\x14\n\x0cmanifestHash\x18\x02 \x01(\x0c\"\'\n\x16\x45xecuteComputeResponse\x12\r\n\x05jobId\x18\x01 \x01(\x0c\"!\n\x10JobStatusRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\"3\n\x11JobStatusResponse\x12\x1e\n\x16\x63ompleteComputeNodeIds\x18\x01 \x03(\t\"9\n\x11GetResultsRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\x12\x15\n\rcomputeNodeId\x18\x02 \x01(\t\"=\n\x15GetResultsSizeRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\x12\x15\n\rcomputeNodeId\x18\x02 \x01(\t\"\'\n\x17GetResultsResponseChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x1a\n\x18GetResultsResponseFooter\"-\n\x17RetrieveDataRoomRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"\xb4\x01\n\x18RetrieveDataRoomResponse\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\x12/\n\x07\x63ommits\x18\x02 \x03(\x0b\x32\x1e.data_room.ConfigurationCommit\x12$\n\x17highLevelRepresentation\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentation\"-\n\x17RetrieveAuditLogRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"\'\n\x18RetrieveAuditLogResponse\x12\x0b\n\x03log\x18\x01 \x01(\x0c\"3\n\x1dRetrieveDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"E\n\x1eRetrieveDataRoomStatusResponse\x12#\n\x06status\x18\x01 \x01(\x0e\x32\x13.gcg.DataRoomStatus\"V\n\x1bUpdateDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12#\n\x06status\x18\x02 \x01(\x0e\x32\x13.gcg.DataRoomStatus\"\x1e\n\x1cUpdateDataRoomStatusResponse\"6\n RetrievePublishedDatasetsRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"X\n\x10PublishedDataset\x12\x0e\n\x06leafId\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12\x13\n\x0b\x64\x61tasetHash\x18\x04 \x01(\x0c\"U\n!RetrievePublishedDatasetsResponse\x12\x30\n\x11publishedDatasets\x18\x01 \x03(\x0b\x32\x15.gcg.PublishedDataset\"C\n\x1dRemovePublishedDatasetRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\x0e\n\x06leafId\x18\x02 \x01(\t\" \n\x1eRemovePublishedDatasetResponse\"\x94\x01\n CreateConfigurationCommitRequest\x12.\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x1e.data_room.ConfigurationCommit\x12$\n\x17highLevelRepresentation\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentation\"5\n!CreateConfigurationCommitResponse\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\"9\n%GenerateMergeApprovalSignatureRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\";\n&GenerateMergeApprovalSignatureResponse\x12\x11\n\tsignature\x18\x01 \x01(\x0c\"\xa0\x02\n\x1fMergeConfigurationCommitRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\x12X\n\x12\x61pprovalSignatures\x18\x02 \x03(\x0b\x32<.gcg.MergeConfigurationCommitRequest.ApprovalSignaturesEntry\x12/\n\"newDataRoomHighLevelRepresentation\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x1a\x39\n\x17\x41pprovalSignaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x42%\n#_newDataRoomHighLevelRepresentation\"A\n+RetrieveCurrentDataRoomConfigurationRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"t\n,RetrieveCurrentDataRoomConfigurationResponse\x12\x37\n\rconfiguration\x18\x01 \x01(\x0b\x32 .data_room.DataRoomConfiguration\x12\x0b\n\x03pin\x18\x02 \x01(\x0c\"?\n+RetrieveConfigurationCommitApproversRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\"A\n,RetrieveConfigurationCommitApproversResponse\x12\x11\n\tapprovers\x18\x01 \x03(\t\"6\n\"RetrieveConfigurationCommitRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\"\x97\x01\n#RetrieveConfigurationCommitResponse\x12.\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x1e.data_room.ConfigurationCommit\x12$\n\x17highLevelRepresentation\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentation\"[\n\x18\x43\x61sAuxiliaryStateRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05index\x18\x02 \x01(\x04\x12\x12\n\x05value\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x08\n\x06_value\"Y\n\x19\x43\x61sAuxiliaryStateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05index\x18\x02 \x01(\x04\x12\x12\n\x05value\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x08\n\x06_value\"/\n\x19ReadAuxiliaryStateRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"F\n\x1aReadAuxiliaryStateResponse\x12(\n\x06values\x18\x02 \x03(\x0b\x32\x18.gcg.AuxiliaryStateValue\"A\n\x13\x41uxiliaryStateValue\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x04\x12\r\n\x05value\x18\x03 \x01(\x0c\"\"\n MergeConfigurationCommitResponse\"|\n\x10\x44riverTaskConfig\x12\x1f\n\x04noop\x18\x01 \x01(\x0b\x32\x0f.gcg.NoopConfigH\x00\x12\x31\n\rstaticContent\x18\x02 \x01(\x0b\x32\x18.gcg.StaticContentConfigH\x00\x42\x14\n\x12\x64river_task_config\"\x0c\n\nNoopConfig\"&\n\x13StaticContentConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"5\n\x1fRetrieveUsedAirlockQuotaRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"P\n RetrieveUsedAirlockQuotaResponse\x12,\n\rairlockQuotas\x18\x01 \x03(\x0b\x32\x15.gcg.AirlockQuotaInfo\"U\n\x10\x41irlockQuotaInfo\x12\x15\n\rairlockNodeId\x18\x01 \x01(\t\x12\x12\n\nquotaBytes\x18\x02 \x01(\x04\x12\x16\n\x0eusedQuotaBytes\x18\x03 \x01(\x04\"+\n\x16GetResultsSizeResponse\x12\x11\n\tsizeBytes\x18\x01 \x01(\x04*)\n\x0e\x44\x61taRoomStatus\x12\n\n\x06\x41\x63tive\x10\x00\x12\x0b\n\x07Stopped\x10\x01\x62\x06proto3')

_DATAROOMSTATUS = DESCRIPTOR.enum_types_by_name['DataRoomStatus']
DataRoomStatus = enum_type_wrapper.EnumTypeWrapper(_DATAROOMSTATUS)
Active = 0
Stopped = 1


_GCGREQUEST = DESCRIPTOR.message_types_by_name['GcgRequest']
_GCGRESPONSE = DESCRIPTOR.message_types_by_name['GcgResponse']
_USERAUTH = DESCRIPTOR.message_types_by_name['UserAuth']
_PKI = DESCRIPTOR.message_types_by_name['Pki']
_CREATEDATAROOMREQUEST = DESCRIPTOR.message_types_by_name['CreateDataRoomRequest']
_CREATEDATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataRoomResponse']
_DATAROOMVALIDATIONERROR = DESCRIPTOR.message_types_by_name['DataRoomValidationError']
_PUBLISHDATASETTODATAROOMREQUEST = DESCRIPTOR.message_types_by_name['PublishDatasetToDataRoomRequest']
_PUBLISHDATASETTODATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['PublishDatasetToDataRoomResponse']
_EXECUTECOMPUTEREQUEST = DESCRIPTOR.message_types_by_name['ExecuteComputeRequest']
_EXECUTECOMPUTEREQUEST_PARAMETERSENTRY = _EXECUTECOMPUTEREQUEST.nested_types_by_name['ParametersEntry']
_EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY = _EXECUTECOMPUTEREQUEST.nested_types_by_name['TestDatasetsEntry']
_EXECUTEDEVELOPMENTCOMPUTEREQUEST = DESCRIPTOR.message_types_by_name['ExecuteDevelopmentComputeRequest']
_EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY = _EXECUTEDEVELOPMENTCOMPUTEREQUEST.nested_types_by_name['ParametersEntry']
_EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY = _EXECUTEDEVELOPMENTCOMPUTEREQUEST.nested_types_by_name['TestDatasetsEntry']
_TESTDATASET = DESCRIPTOR.message_types_by_name['TestDataset']
_EXECUTECOMPUTERESPONSE = DESCRIPTOR.message_types_by_name['ExecuteComputeResponse']
_JOBSTATUSREQUEST = DESCRIPTOR.message_types_by_name['JobStatusRequest']
_JOBSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['JobStatusResponse']
_GETRESULTSREQUEST = DESCRIPTOR.message_types_by_name['GetResultsRequest']
_GETRESULTSSIZEREQUEST = DESCRIPTOR.message_types_by_name['GetResultsSizeRequest']
_GETRESULTSRESPONSECHUNK = DESCRIPTOR.message_types_by_name['GetResultsResponseChunk']
_GETRESULTSRESPONSEFOOTER = DESCRIPTOR.message_types_by_name['GetResultsResponseFooter']
_RETRIEVEDATAROOMREQUEST = DESCRIPTOR.message_types_by_name['RetrieveDataRoomRequest']
_RETRIEVEDATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveDataRoomResponse']
_RETRIEVEAUDITLOGREQUEST = DESCRIPTOR.message_types_by_name['RetrieveAuditLogRequest']
_RETRIEVEAUDITLOGRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveAuditLogResponse']
_RETRIEVEDATAROOMSTATUSREQUEST = DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusRequest']
_RETRIEVEDATAROOMSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusResponse']
_UPDATEDATAROOMSTATUSREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusRequest']
_UPDATEDATAROOMSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusResponse']
_RETRIEVEPUBLISHEDDATASETSREQUEST = DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetsRequest']
_PUBLISHEDDATASET = DESCRIPTOR.message_types_by_name['PublishedDataset']
_RETRIEVEPUBLISHEDDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetsResponse']
_REMOVEPUBLISHEDDATASETREQUEST = DESCRIPTOR.message_types_by_name['RemovePublishedDatasetRequest']
_REMOVEPUBLISHEDDATASETRESPONSE = DESCRIPTOR.message_types_by_name['RemovePublishedDatasetResponse']
_CREATECONFIGURATIONCOMMITREQUEST = DESCRIPTOR.message_types_by_name['CreateConfigurationCommitRequest']
_CREATECONFIGURATIONCOMMITRESPONSE = DESCRIPTOR.message_types_by_name['CreateConfigurationCommitResponse']
_GENERATEMERGEAPPROVALSIGNATUREREQUEST = DESCRIPTOR.message_types_by_name['GenerateMergeApprovalSignatureRequest']
_GENERATEMERGEAPPROVALSIGNATURERESPONSE = DESCRIPTOR.message_types_by_name['GenerateMergeApprovalSignatureResponse']
_MERGECONFIGURATIONCOMMITREQUEST = DESCRIPTOR.message_types_by_name['MergeConfigurationCommitRequest']
_MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY = _MERGECONFIGURATIONCOMMITREQUEST.nested_types_by_name['ApprovalSignaturesEntry']
_RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST = DESCRIPTOR.message_types_by_name['RetrieveCurrentDataRoomConfigurationRequest']
_RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveCurrentDataRoomConfigurationResponse']
_RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitApproversRequest']
_RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitApproversResponse']
_RETRIEVECONFIGURATIONCOMMITREQUEST = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitRequest']
_RETRIEVECONFIGURATIONCOMMITRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitResponse']
_CASAUXILIARYSTATEREQUEST = DESCRIPTOR.message_types_by_name['CasAuxiliaryStateRequest']
_CASAUXILIARYSTATERESPONSE = DESCRIPTOR.message_types_by_name['CasAuxiliaryStateResponse']
_READAUXILIARYSTATEREQUEST = DESCRIPTOR.message_types_by_name['ReadAuxiliaryStateRequest']
_READAUXILIARYSTATERESPONSE = DESCRIPTOR.message_types_by_name['ReadAuxiliaryStateResponse']
_AUXILIARYSTATEVALUE = DESCRIPTOR.message_types_by_name['AuxiliaryStateValue']
_MERGECONFIGURATIONCOMMITRESPONSE = DESCRIPTOR.message_types_by_name['MergeConfigurationCommitResponse']
_DRIVERTASKCONFIG = DESCRIPTOR.message_types_by_name['DriverTaskConfig']
_NOOPCONFIG = DESCRIPTOR.message_types_by_name['NoopConfig']
_STATICCONTENTCONFIG = DESCRIPTOR.message_types_by_name['StaticContentConfig']
_RETRIEVEUSEDAIRLOCKQUOTAREQUEST = DESCRIPTOR.message_types_by_name['RetrieveUsedAirlockQuotaRequest']
_RETRIEVEUSEDAIRLOCKQUOTARESPONSE = DESCRIPTOR.message_types_by_name['RetrieveUsedAirlockQuotaResponse']
_AIRLOCKQUOTAINFO = DESCRIPTOR.message_types_by_name['AirlockQuotaInfo']
_GETRESULTSSIZERESPONSE = DESCRIPTOR.message_types_by_name['GetResultsSizeResponse']
GcgRequest = _reflection.GeneratedProtocolMessageType('GcgRequest', (_message.Message,), {
  'DESCRIPTOR' : _GCGREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GcgRequest)
  })
_sym_db.RegisterMessage(GcgRequest)

GcgResponse = _reflection.GeneratedProtocolMessageType('GcgResponse', (_message.Message,), {
  'DESCRIPTOR' : _GCGRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GcgResponse)
  })
_sym_db.RegisterMessage(GcgResponse)

UserAuth = _reflection.GeneratedProtocolMessageType('UserAuth', (_message.Message,), {
  'DESCRIPTOR' : _USERAUTH,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.UserAuth)
  })
_sym_db.RegisterMessage(UserAuth)

Pki = _reflection.GeneratedProtocolMessageType('Pki', (_message.Message,), {
  'DESCRIPTOR' : _PKI,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.Pki)
  })
_sym_db.RegisterMessage(Pki)

CreateDataRoomRequest = _reflection.GeneratedProtocolMessageType('CreateDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateDataRoomRequest)
  })
_sym_db.RegisterMessage(CreateDataRoomRequest)

CreateDataRoomResponse = _reflection.GeneratedProtocolMessageType('CreateDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateDataRoomResponse)
  })
_sym_db.RegisterMessage(CreateDataRoomResponse)

DataRoomValidationError = _reflection.GeneratedProtocolMessageType('DataRoomValidationError', (_message.Message,), {
  'DESCRIPTOR' : _DATAROOMVALIDATIONERROR,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.DataRoomValidationError)
  })
_sym_db.RegisterMessage(DataRoomValidationError)

PublishDatasetToDataRoomRequest = _reflection.GeneratedProtocolMessageType('PublishDatasetToDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATASETTODATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishDatasetToDataRoomRequest)
  })
_sym_db.RegisterMessage(PublishDatasetToDataRoomRequest)

PublishDatasetToDataRoomResponse = _reflection.GeneratedProtocolMessageType('PublishDatasetToDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATASETTODATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishDatasetToDataRoomResponse)
  })
_sym_db.RegisterMessage(PublishDatasetToDataRoomResponse)

ExecuteComputeRequest = _reflection.GeneratedProtocolMessageType('ExecuteComputeRequest', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTECOMPUTEREQUEST_PARAMETERSENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeRequest.ParametersEntry)
    })
  ,

  'TestDatasetsEntry' : _reflection.GeneratedProtocolMessageType('TestDatasetsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeRequest.TestDatasetsEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTECOMPUTEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeRequest)
  })
_sym_db.RegisterMessage(ExecuteComputeRequest)
_sym_db.RegisterMessage(ExecuteComputeRequest.ParametersEntry)
_sym_db.RegisterMessage(ExecuteComputeRequest.TestDatasetsEntry)

ExecuteDevelopmentComputeRequest = _reflection.GeneratedProtocolMessageType('ExecuteDevelopmentComputeRequest', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.ExecuteDevelopmentComputeRequest.ParametersEntry)
    })
  ,

  'TestDatasetsEntry' : _reflection.GeneratedProtocolMessageType('TestDatasetsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.ExecuteDevelopmentComputeRequest.TestDatasetsEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTEDEVELOPMENTCOMPUTEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteDevelopmentComputeRequest)
  })
_sym_db.RegisterMessage(ExecuteDevelopmentComputeRequest)
_sym_db.RegisterMessage(ExecuteDevelopmentComputeRequest.ParametersEntry)
_sym_db.RegisterMessage(ExecuteDevelopmentComputeRequest.TestDatasetsEntry)

TestDataset = _reflection.GeneratedProtocolMessageType('TestDataset', (_message.Message,), {
  'DESCRIPTOR' : _TESTDATASET,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.TestDataset)
  })
_sym_db.RegisterMessage(TestDataset)

ExecuteComputeResponse = _reflection.GeneratedProtocolMessageType('ExecuteComputeResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTECOMPUTERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeResponse)
  })
_sym_db.RegisterMessage(ExecuteComputeResponse)

JobStatusRequest = _reflection.GeneratedProtocolMessageType('JobStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.JobStatusRequest)
  })
_sym_db.RegisterMessage(JobStatusRequest)

JobStatusResponse = _reflection.GeneratedProtocolMessageType('JobStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.JobStatusResponse)
  })
_sym_db.RegisterMessage(JobStatusResponse)

GetResultsRequest = _reflection.GeneratedProtocolMessageType('GetResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsRequest)
  })
_sym_db.RegisterMessage(GetResultsRequest)

GetResultsSizeRequest = _reflection.GeneratedProtocolMessageType('GetResultsSizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSSIZEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsSizeRequest)
  })
_sym_db.RegisterMessage(GetResultsSizeRequest)

GetResultsResponseChunk = _reflection.GeneratedProtocolMessageType('GetResultsResponseChunk', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSECHUNK,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsResponseChunk)
  })
_sym_db.RegisterMessage(GetResultsResponseChunk)

GetResultsResponseFooter = _reflection.GeneratedProtocolMessageType('GetResultsResponseFooter', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSEFOOTER,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsResponseFooter)
  })
_sym_db.RegisterMessage(GetResultsResponseFooter)

RetrieveDataRoomRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomRequest)

RetrieveDataRoomResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomResponse)

RetrieveAuditLogRequest = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveAuditLogRequest)
  })
_sym_db.RegisterMessage(RetrieveAuditLogRequest)

RetrieveAuditLogResponse = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveAuditLogResponse)
  })
_sym_db.RegisterMessage(RetrieveAuditLogResponse)

RetrieveDataRoomStatusRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomStatusRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusRequest)

RetrieveDataRoomStatusResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomStatusResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusResponse)

UpdateDataRoomStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.UpdateDataRoomStatusRequest)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusRequest)

UpdateDataRoomStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.UpdateDataRoomStatusResponse)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusResponse)

RetrievePublishedDatasetsRequest = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrievePublishedDatasetsRequest)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetsRequest)

PublishedDataset = _reflection.GeneratedProtocolMessageType('PublishedDataset', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHEDDATASET,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishedDataset)
  })
_sym_db.RegisterMessage(PublishedDataset)

RetrievePublishedDatasetsResponse = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrievePublishedDatasetsResponse)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetsResponse)

RemovePublishedDatasetRequest = _reflection.GeneratedProtocolMessageType('RemovePublishedDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPUBLISHEDDATASETREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RemovePublishedDatasetRequest)
  })
_sym_db.RegisterMessage(RemovePublishedDatasetRequest)

RemovePublishedDatasetResponse = _reflection.GeneratedProtocolMessageType('RemovePublishedDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPUBLISHEDDATASETRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RemovePublishedDatasetResponse)
  })
_sym_db.RegisterMessage(RemovePublishedDatasetResponse)

CreateConfigurationCommitRequest = _reflection.GeneratedProtocolMessageType('CreateConfigurationCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONFIGURATIONCOMMITREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateConfigurationCommitRequest)
  })
_sym_db.RegisterMessage(CreateConfigurationCommitRequest)

CreateConfigurationCommitResponse = _reflection.GeneratedProtocolMessageType('CreateConfigurationCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONFIGURATIONCOMMITRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateConfigurationCommitResponse)
  })
_sym_db.RegisterMessage(CreateConfigurationCommitResponse)

GenerateMergeApprovalSignatureRequest = _reflection.GeneratedProtocolMessageType('GenerateMergeApprovalSignatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEMERGEAPPROVALSIGNATUREREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GenerateMergeApprovalSignatureRequest)
  })
_sym_db.RegisterMessage(GenerateMergeApprovalSignatureRequest)

GenerateMergeApprovalSignatureResponse = _reflection.GeneratedProtocolMessageType('GenerateMergeApprovalSignatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEMERGEAPPROVALSIGNATURERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GenerateMergeApprovalSignatureResponse)
  })
_sym_db.RegisterMessage(GenerateMergeApprovalSignatureResponse)

MergeConfigurationCommitRequest = _reflection.GeneratedProtocolMessageType('MergeConfigurationCommitRequest', (_message.Message,), {

  'ApprovalSignaturesEntry' : _reflection.GeneratedProtocolMessageType('ApprovalSignaturesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.MergeConfigurationCommitRequest.ApprovalSignaturesEntry)
    })
  ,
  'DESCRIPTOR' : _MERGECONFIGURATIONCOMMITREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.MergeConfigurationCommitRequest)
  })
_sym_db.RegisterMessage(MergeConfigurationCommitRequest)
_sym_db.RegisterMessage(MergeConfigurationCommitRequest.ApprovalSignaturesEntry)

RetrieveCurrentDataRoomConfigurationRequest = _reflection.GeneratedProtocolMessageType('RetrieveCurrentDataRoomConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveCurrentDataRoomConfigurationRequest)
  })
_sym_db.RegisterMessage(RetrieveCurrentDataRoomConfigurationRequest)

RetrieveCurrentDataRoomConfigurationResponse = _reflection.GeneratedProtocolMessageType('RetrieveCurrentDataRoomConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveCurrentDataRoomConfigurationResponse)
  })
_sym_db.RegisterMessage(RetrieveCurrentDataRoomConfigurationResponse)

RetrieveConfigurationCommitApproversRequest = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitApproversRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitApproversRequest)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitApproversRequest)

RetrieveConfigurationCommitApproversResponse = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitApproversResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitApproversResponse)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitApproversResponse)

RetrieveConfigurationCommitRequest = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitRequest)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitRequest)

RetrieveConfigurationCommitResponse = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitResponse)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitResponse)

CasAuxiliaryStateRequest = _reflection.GeneratedProtocolMessageType('CasAuxiliaryStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _CASAUXILIARYSTATEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CasAuxiliaryStateRequest)
  })
_sym_db.RegisterMessage(CasAuxiliaryStateRequest)

CasAuxiliaryStateResponse = _reflection.GeneratedProtocolMessageType('CasAuxiliaryStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _CASAUXILIARYSTATERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CasAuxiliaryStateResponse)
  })
_sym_db.RegisterMessage(CasAuxiliaryStateResponse)

ReadAuxiliaryStateRequest = _reflection.GeneratedProtocolMessageType('ReadAuxiliaryStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _READAUXILIARYSTATEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ReadAuxiliaryStateRequest)
  })
_sym_db.RegisterMessage(ReadAuxiliaryStateRequest)

ReadAuxiliaryStateResponse = _reflection.GeneratedProtocolMessageType('ReadAuxiliaryStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _READAUXILIARYSTATERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ReadAuxiliaryStateResponse)
  })
_sym_db.RegisterMessage(ReadAuxiliaryStateResponse)

AuxiliaryStateValue = _reflection.GeneratedProtocolMessageType('AuxiliaryStateValue', (_message.Message,), {
  'DESCRIPTOR' : _AUXILIARYSTATEVALUE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.AuxiliaryStateValue)
  })
_sym_db.RegisterMessage(AuxiliaryStateValue)

MergeConfigurationCommitResponse = _reflection.GeneratedProtocolMessageType('MergeConfigurationCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _MERGECONFIGURATIONCOMMITRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.MergeConfigurationCommitResponse)
  })
_sym_db.RegisterMessage(MergeConfigurationCommitResponse)

DriverTaskConfig = _reflection.GeneratedProtocolMessageType('DriverTaskConfig', (_message.Message,), {
  'DESCRIPTOR' : _DRIVERTASKCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.DriverTaskConfig)
  })
_sym_db.RegisterMessage(DriverTaskConfig)

NoopConfig = _reflection.GeneratedProtocolMessageType('NoopConfig', (_message.Message,), {
  'DESCRIPTOR' : _NOOPCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.NoopConfig)
  })
_sym_db.RegisterMessage(NoopConfig)

StaticContentConfig = _reflection.GeneratedProtocolMessageType('StaticContentConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATICCONTENTCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.StaticContentConfig)
  })
_sym_db.RegisterMessage(StaticContentConfig)

RetrieveUsedAirlockQuotaRequest = _reflection.GeneratedProtocolMessageType('RetrieveUsedAirlockQuotaRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEUSEDAIRLOCKQUOTAREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveUsedAirlockQuotaRequest)
  })
_sym_db.RegisterMessage(RetrieveUsedAirlockQuotaRequest)

RetrieveUsedAirlockQuotaResponse = _reflection.GeneratedProtocolMessageType('RetrieveUsedAirlockQuotaResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEUSEDAIRLOCKQUOTARESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveUsedAirlockQuotaResponse)
  })
_sym_db.RegisterMessage(RetrieveUsedAirlockQuotaResponse)

AirlockQuotaInfo = _reflection.GeneratedProtocolMessageType('AirlockQuotaInfo', (_message.Message,), {
  'DESCRIPTOR' : _AIRLOCKQUOTAINFO,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.AirlockQuotaInfo)
  })
_sym_db.RegisterMessage(AirlockQuotaInfo)

GetResultsSizeResponse = _reflection.GeneratedProtocolMessageType('GetResultsSizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSSIZERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsSizeResponse)
  })
_sym_db.RegisterMessage(GetResultsSizeResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXECUTECOMPUTEREQUEST_PARAMETERSENTRY._options = None
  _EXECUTECOMPUTEREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY._options = None
  _EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY._serialized_options = b'8\001'
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY._options = None
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY._options = None
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY._serialized_options = b'8\001'
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._options = None
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._serialized_options = b'8\001'
  _DATAROOMSTATUS._serialized_start=8712
  _DATAROOMSTATUS._serialized_end=8753
  _GCGREQUEST._serialized_start=64
  _GCGREQUEST._serialized_end=1858
  _GCGRESPONSE._serialized_start=1861
  _GCGRESPONSE._serialized_end=3681
  _USERAUTH._serialized_start=3683
  _USERAUTH._serialized_end=3788
  _PKI._serialized_start=3790
  _PKI._serialized_end=3851
  _CREATEDATAROOMREQUEST._serialized_start=3854
  _CREATEDATAROOMREQUEST._serialized_end=4034
  _CREATEDATAROOMRESPONSE._serialized_start=4037
  _CREATEDATAROOMRESPONSE._serialized_end=4177
  _DATAROOMVALIDATIONERROR._serialized_start=4180
  _DATAROOMVALIDATIONERROR._serialized_end=4506
  _PUBLISHDATASETTODATAROOMREQUEST._serialized_start=4509
  _PUBLISHDATASETTODATAROOMREQUEST._serialized_end=4637
  _PUBLISHDATASETTODATAROOMRESPONSE._serialized_start=4639
  _PUBLISHDATASETTODATAROOMRESPONSE._serialized_end=4673
  _EXECUTECOMPUTEREQUEST._serialized_start=4676
  _EXECUTECOMPUTEREQUEST._serialized_end=5030
  _EXECUTECOMPUTEREQUEST_PARAMETERSENTRY._serialized_start=4910
  _EXECUTECOMPUTEREQUEST_PARAMETERSENTRY._serialized_end=4959
  _EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY._serialized_start=4961
  _EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY._serialized_end=5030
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST._serialized_start=5033
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST._serialized_end=5431
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY._serialized_start=4910
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY._serialized_end=4959
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY._serialized_start=4961
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY._serialized_end=5030
  _TESTDATASET._serialized_start=5433
  _TESTDATASET._serialized_end=5491
  _EXECUTECOMPUTERESPONSE._serialized_start=5493
  _EXECUTECOMPUTERESPONSE._serialized_end=5532
  _JOBSTATUSREQUEST._serialized_start=5534
  _JOBSTATUSREQUEST._serialized_end=5567
  _JOBSTATUSRESPONSE._serialized_start=5569
  _JOBSTATUSRESPONSE._serialized_end=5620
  _GETRESULTSREQUEST._serialized_start=5622
  _GETRESULTSREQUEST._serialized_end=5679
  _GETRESULTSSIZEREQUEST._serialized_start=5681
  _GETRESULTSSIZEREQUEST._serialized_end=5742
  _GETRESULTSRESPONSECHUNK._serialized_start=5744
  _GETRESULTSRESPONSECHUNK._serialized_end=5783
  _GETRESULTSRESPONSEFOOTER._serialized_start=5785
  _GETRESULTSRESPONSEFOOTER._serialized_end=5811
  _RETRIEVEDATAROOMREQUEST._serialized_start=5813
  _RETRIEVEDATAROOMREQUEST._serialized_end=5858
  _RETRIEVEDATAROOMRESPONSE._serialized_start=5861
  _RETRIEVEDATAROOMRESPONSE._serialized_end=6041
  _RETRIEVEAUDITLOGREQUEST._serialized_start=6043
  _RETRIEVEAUDITLOGREQUEST._serialized_end=6088
  _RETRIEVEAUDITLOGRESPONSE._serialized_start=6090
  _RETRIEVEAUDITLOGRESPONSE._serialized_end=6129
  _RETRIEVEDATAROOMSTATUSREQUEST._serialized_start=6131
  _RETRIEVEDATAROOMSTATUSREQUEST._serialized_end=6182
  _RETRIEVEDATAROOMSTATUSRESPONSE._serialized_start=6184
  _RETRIEVEDATAROOMSTATUSRESPONSE._serialized_end=6253
  _UPDATEDATAROOMSTATUSREQUEST._serialized_start=6255
  _UPDATEDATAROOMSTATUSREQUEST._serialized_end=6341
  _UPDATEDATAROOMSTATUSRESPONSE._serialized_start=6343
  _UPDATEDATAROOMSTATUSRESPONSE._serialized_end=6373
  _RETRIEVEPUBLISHEDDATASETSREQUEST._serialized_start=6375
  _RETRIEVEPUBLISHEDDATASETSREQUEST._serialized_end=6429
  _PUBLISHEDDATASET._serialized_start=6431
  _PUBLISHEDDATASET._serialized_end=6519
  _RETRIEVEPUBLISHEDDATASETSRESPONSE._serialized_start=6521
  _RETRIEVEPUBLISHEDDATASETSRESPONSE._serialized_end=6606
  _REMOVEPUBLISHEDDATASETREQUEST._serialized_start=6608
  _REMOVEPUBLISHEDDATASETREQUEST._serialized_end=6675
  _REMOVEPUBLISHEDDATASETRESPONSE._serialized_start=6677
  _REMOVEPUBLISHEDDATASETRESPONSE._serialized_end=6709
  _CREATECONFIGURATIONCOMMITREQUEST._serialized_start=6712
  _CREATECONFIGURATIONCOMMITREQUEST._serialized_end=6860
  _CREATECONFIGURATIONCOMMITRESPONSE._serialized_start=6862
  _CREATECONFIGURATIONCOMMITRESPONSE._serialized_end=6915
  _GENERATEMERGEAPPROVALSIGNATUREREQUEST._serialized_start=6917
  _GENERATEMERGEAPPROVALSIGNATUREREQUEST._serialized_end=6974
  _GENERATEMERGEAPPROVALSIGNATURERESPONSE._serialized_start=6976
  _GENERATEMERGEAPPROVALSIGNATURERESPONSE._serialized_end=7035
  _MERGECONFIGURATIONCOMMITREQUEST._serialized_start=7038
  _MERGECONFIGURATIONCOMMITREQUEST._serialized_end=7326
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._serialized_start=7230
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._serialized_end=7287
  _RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST._serialized_start=7328
  _RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST._serialized_end=7393
  _RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE._serialized_start=7395
  _RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE._serialized_end=7511
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST._serialized_start=7513
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST._serialized_end=7576
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE._serialized_start=7578
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE._serialized_end=7643
  _RETRIEVECONFIGURATIONCOMMITREQUEST._serialized_start=7645
  _RETRIEVECONFIGURATIONCOMMITREQUEST._serialized_end=7699
  _RETRIEVECONFIGURATIONCOMMITRESPONSE._serialized_start=7702
  _RETRIEVECONFIGURATIONCOMMITRESPONSE._serialized_end=7853
  _CASAUXILIARYSTATEREQUEST._serialized_start=7855
  _CASAUXILIARYSTATEREQUEST._serialized_end=7946
  _CASAUXILIARYSTATERESPONSE._serialized_start=7948
  _CASAUXILIARYSTATERESPONSE._serialized_end=8037
  _READAUXILIARYSTATEREQUEST._serialized_start=8039
  _READAUXILIARYSTATEREQUEST._serialized_end=8086
  _READAUXILIARYSTATERESPONSE._serialized_start=8088
  _READAUXILIARYSTATERESPONSE._serialized_end=8158
  _AUXILIARYSTATEVALUE._serialized_start=8160
  _AUXILIARYSTATEVALUE._serialized_end=8225
  _MERGECONFIGURATIONCOMMITRESPONSE._serialized_start=8227
  _MERGECONFIGURATIONCOMMITRESPONSE._serialized_end=8261
  _DRIVERTASKCONFIG._serialized_start=8263
  _DRIVERTASKCONFIG._serialized_end=8387
  _NOOPCONFIG._serialized_start=8389
  _NOOPCONFIG._serialized_end=8401
  _STATICCONTENTCONFIG._serialized_start=8403
  _STATICCONTENTCONFIG._serialized_end=8441
  _RETRIEVEUSEDAIRLOCKQUOTAREQUEST._serialized_start=8443
  _RETRIEVEUSEDAIRLOCKQUOTAREQUEST._serialized_end=8496
  _RETRIEVEUSEDAIRLOCKQUOTARESPONSE._serialized_start=8498
  _RETRIEVEUSEDAIRLOCKQUOTARESPONSE._serialized_end=8578
  _AIRLOCKQUOTAINFO._serialized_start=8580
  _AIRLOCKQUOTAINFO._serialized_end=8665
  _GETRESULTSSIZERESPONSE._serialized_start=8667
  _GETRESULTSSIZERESPONSE._serialized_end=8710
# @@protoc_insertion_point(module_scope)



from __future__ import annotations

from enum import Enum
from .high_level_node import ContainerComputationNode
from typing import Dict, List, Optional
from .node_definitions import NodeDefinition
from ..session import Session
from dataclasses import dataclass
from .table_data_nodes import PrimitiveType
from typing_extensions import Self
from decentriq_dcr_compiler.schemas.data_science_data_room import (
    SyntheticDataComputationNode,
)
import json
from .sql_helper import read_sql_query_result_as_string


class MaskType(str, Enum):
    GENERIC_STRING = "genericString"
    GENERIC_NUMBER = "genericNumber"
    NAME = "name"
    ADDRESS = "address"
    POSTCODE = "postcode"
    PHONE_NUMBER = "phoneNumber"
    SOCIAL_SECURITY_NUMBER = "socialSecurityNumber"
    EMAIL = "email"
    DATE = "date"
    TIMESTAMP = "timestamp"
    IBAN = "iban"


@dataclass
class SyntheticNodeColumn:
    data_type: PrimitiveType
    index: int
    mask_type: MaskType
    should_mask_column: bool
    is_nullable: bool = True
    name: Optional[Optional[str]] = None


class SyntheticDataComputeNodeDefinition(NodeDefinition):
    """
    Class representing a Synthetic Data Computation node.
    """

    def __init__(
        self,
        name: str,
        columns: List[SyntheticNodeColumn],
        dependency: str,
        epsilon: float,
        output_original_data_statistics: bool = False,
        enable_logs_on_error: bool = False,
        enable_logs_on_success: bool = False,
        id: Optional[str] = None,
    ) -> None:
        """
        Initialise a `SyntheticDataComputeNodeDefinition`:

        **Parameters**:
        - `name`: Name of the `SyntheticDataComputeNodeDefinition`.
        - `columns`: Columns defined for the `SyntheticDataComputeNodeDefinition`
        - `dependency`: Node that the `SyntheticDataComputeNodeDefinition` depends on.
        - `epsilon`: Amount of noise to add to the data.
        - `output_original_data_statistics`: Include the original statistics in the output.
        - `enable_logs_on_error`: Enable logs in the event of an error.
        - `enable_logs_on_success`: Enable logs when the computation is successful.
        - `id`: Optional ID  of the `SyntheticDataComputeNodeDefinition`.
        """
        super().__init__(name=name, id=id or name)
        self.columns = columns
        self.dependency = dependency
        self.epsilon = epsilon
        self.output_original_data_statistics = output_original_data_statistics
        self.enable_logs_on_error = enable_logs_on_error
        self.enable_logs_on_success = enable_logs_on_success
        self.specification_id = "decentriq.python-synth-data-worker-32-64"
        self.static_content_specification_id = "decentriq.driver"

    @property
    def required_workers(self):
        return [self.static_content_specification_id, self.specification_id]

    def _get_high_level_representation(self) -> Dict[str, str]:
        """
        Retrieve the high level representation of the `SyntheticDataComputeNodeDefinition`.
        """
        columns = []
        for column in self.columns:
            columns.append(
                {
                    "dataFormat": {
                        "dataType": column.data_type.value,
                        "isNullable": column.is_nullable,
                    },
                    "index": column.index,
                    "maskType": column.mask_type.value,
                    "shouldMaskColumn": column.should_mask_column,
                    "name": "" if not column.name else column.name,
                }
            )

        computation_node = {
            "id": self.id,
            "name": self.name,
            "kind": {
                "computation": {
                    "kind": {
                        "syntheticData": {
                            "columns": columns,
                            "dependency": self.dependency,
                            "enableLogsOnError": self.enable_logs_on_error,
                            "enableLogsOnSuccess": self.enable_logs_on_success,
                            "epsilon": self.epsilon,
                            "outputOriginalDataStatistics": self.output_original_data_statistics,
                            "staticContentSpecificationId": self.static_content_specification_id,
                            "synthSpecificationId": self.specification_id,
                        }
                    }
                },
            },
        }
        return computation_node

    @staticmethod
    def _from_high_level(
        id: str, name: str, node: SyntheticDataComputationNode
    ) -> Self:
        """
        Instantiate a `SyntheticDataComputeNodeDefinition` from its high level representation.

        **Parameters**:
        - `name`: Name of the `SyntheticDataComputeNodeDefinition`.
        - `node`: Pydantic model of the `SyntheticDataComputeNode`.
        """
        synthetic_data_node = json.loads(node.model_dump_json())
        return SyntheticDataComputeNodeDefinition(
            id=id,
            name=name,
            columns=synthetic_data_node["columns"],
            dependency=synthetic_data_node["dependency"],
            epsilon=synthetic_data_node["epsilon"],
            output_original_data_statistics=synthetic_data_node[
                "outputOriginalDataStatistics"
            ],
            enable_logs_on_error=synthetic_data_node["enableLogsOnError"],
            enable_logs_on_success=synthetic_data_node["enableLogsOnSuccess"],
        )

    def build(
        self,
        dcr_id: str,
        node_definition: NodeDefinition,
        client: Client,
        session: Session,
    ) -> SyntheticDataComputeNode:
        """
        Construct a SyntheticDataComputeNode from the Node Definition.

        **Parameters**:
        - `dcr_id`: ID of the DCR the node is a member of.
        - `node_definition`: Definition of the Synthetic Data Compute Node.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        """
        return SyntheticDataComputeNode(
            name=self.name,
            dcr_id=dcr_id,
            columns=self.columns,
            dependency=self.dependency,
            epsilon=self.epsilon,
            client=client,
            session=session,
            node_definition=node_definition,
            output_original_data_statistics=self.output_original_data_statistics,
            enable_logs_on_error=self.enable_logs_on_error,
            enable_logs_on_success=self.enable_logs_on_success,
            id=self.id,
        )


class SyntheticDataComputeNode(ContainerComputationNode):
    """
    Class representing a Synthetic Data Computation Node.
    """

    def __init__(
        self,
        id: str,
        name: str,
        dcr_id: str,
        columns: List[SyntheticNodeColumn],
        dependency: str,
        epsilon: float,
        client: Client,
        session: Session,
        node_definition: NodeDefinition,
        output_original_data_statistics: bool = False,
        enable_logs_on_error: bool = False,
        enable_logs_on_success: bool = False,
    ) -> None:
        """
        Initialise a `SyntheticDataComputeNode`:

        **Parameters**:
        - `id`: ID of the `SyntheticDataComputeNode`.
        - `name`: Name of the `SyntheticDataComputeNode`.
        - `dcr_id`: ID of the DCR the node is a member of.
        - `columns`: Columns defined for the `SyntheticDataComputeNode`
        - `dependency`: Node that the `SyntheticDataComputeNode` depends on.
        - `epsilon`: Amount of noise to add to the data.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        - `output_original_data_statistics`: Include the original statistics in the output.
        - `enable_logs_on_error`: Enable logs in the event of an error.
        - `enable_logs_on_success`: Enable logs when the computation is successful.
        """
        super().__init__(
            name=name,
            client=client,
            session=session,
            dcr_id=dcr_id,
            id=id,
            definition=node_definition,
        )
        self.columns = columns
        self.dependency = dependency
        self.epsilon = epsilon
        self.output_original_data_statistics = output_original_data_statistics
        self.enable_logs_on_error = enable_logs_on_error
        self.enable_logs_on_success = enable_logs_on_success
        self.specification_id = "decentriq.python-synth-data-worker-32-64"
        self.static_content_specification_id = "decentriq.driver"

    def get_results_as_string(
        self,
        interval: int = 5,
        timeout: Optional[int] = None,
    ) -> Optional[str]:
        """
        Retrieve the results of a computation as a string.

        **Parameters**:
        - `interval`: Time interval (in seconds) to check for results.
        - `timeout`: Time (in seconds) after which results are no longer checked.
        """
        raw_result = self.get_results_as_bytes(interval=interval, timeout=timeout)
        if raw_result:
            return read_sql_query_result_as_string(raw_result)
        else:
            return None

    def run_computation_and_get_results_as_string(
        self,
        interval: int = 5,
        timeout: Optional[int] = None,
    ) -> Optional[str]:
        """
        This is a blocking call to run a computation and get the results as a
        string.

        **Parameters**:
        - `interval`: Time interval (in seconds) to check for results.
        - `timeout`: Time (in seconds) after which results are no longer checked.
        """
        raw_result = self.run_computation_and_get_results_as_bytes(
            interval=interval, timeout=timeout
        )
        if raw_result:
            return read_sql_query_result_as_string(raw_result)
        else:
            return None

    def _get_computation_id(self) -> str:
        """
        Retrieve the ID of the node corresponding to the computation.
        """
        return f"{self.id}_container"



from __future__ import annotations

from enum import Enum
from decentriq_dcr_compiler.schemas.data_science_data_room import S3SinkComputationNode
from .high_level_node import ComputationNode
from typing import Dict, Optional
from .node_definitions import NodeDefinition
from ..session import Session
from typing_extensions import Self
import json


class S3Provider(str, Enum):
    AWS = "Aws"
    GCS = "Gcs"


class S3SinkComputeNodeDefinition(NodeDefinition):
    """
    Class representing an S3 Sink Computation node.
    """

    def __init__(
        self,
        name: str,
        credentials_dependency_id: str,
        endpoint: str,
        region: str,
        dependency: str,
        provider: Optional[S3Provider] = S3Provider.AWS,
        id: Optional[str] = None,
    ) -> None:
        """
        Initialise a `S3SinkComputeNodeDefinition`:

        **Parameters**:
        `name`: Name of the `S3SinkComputeNodeDefinition`.
        `credentials_dependency_id`: ID of the `S3SinkComputeNodeDefinition` dependency.
        `endpoint`: Endpoint where data will be uploaded.
        `region`: Region where the data will be uploaded.
        `dependency`: Node that the `S3SinkComputeNodeDefinition` depends on.
        `provider`: Type of S3 provider (AWS/GCS).
        `id`: Optional ID of the `S3SinkComputeNodeDefinition`.
        """
        super().__init__(name=name, id=id or name)
        self.credentials_dependency_id = credentials_dependency_id
        self.endpoint = endpoint
        self.region = region
        self.dependency = dependency
        self.provider = provider
        self.specification_id = "decentriq.s3-sink-worker"

    @property
    def required_workers(self):
        return [self.specification_id]

    def _get_high_level_representation(self) -> Dict[str, str]:
        """
        Retrieve the high level representation of the `S3SinkComputeNodeDefinition`.
        """
        computation_node = {
            "id": self.id,
            "name": self.name,
            "kind": {
                "computation": {
                    "kind": {
                        "s3Sink": {
                            "credentialsDependencyId": self.credentials_dependency_id,
                            "endpoint": self.endpoint,
                            "region": self.region,
                            "s3Provider": self.provider.value,
                            "specificationId": self.specification_id,
                            "uploadDependencyId": self.dependency,
                        }
                    }
                },
            },
        }
        return computation_node

    @staticmethod
    def _from_high_level(id: str, name: str, node: S3SinkComputationNode) -> Self:
        """
        Instantiate a `S3SinkComputeNodeDefinition` from its high level representation.

        **Parameters**:
        - `name`: Name of the `S3SinkComputeNodeDefinition`.
        - `node`: Pydantic model of the `S3SinkComputeNode`.
        """
        s3_sink_node = json.loads(node.model_dump_json())
        return S3SinkComputeNodeDefinition(
            name=name,
            credentials_dependency_id=s3_sink_node["credentialsDependencyId"],
            endpoint=s3_sink_node["endpoint"],
            region=s3_sink_node["region"],
            dependency=s3_sink_node["uploadDependencyId"],
            provider=s3_sink_node["s3Provider"],
            id=id,
        )

    def build(
        self,
        dcr_id: str,
        node_definition: NodeDefinition,
        client: Client,
        session: Session,
    ) -> S3SinkComputeNode:
        """
        Construct a S3SinkComputeNode from the Node Definition.

        **Parameters**:
        - `dcr_id`: ID of the DCR the node is a member of.
        - `node_definition`: Definition of the S3 Sink Compute Node.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        """
        return S3SinkComputeNode(
            name=self.name,
            dcr_id=dcr_id,
            credentials_dependency_id=self.credentials_dependency_id,
            endpoint=self.endpoint,
            region=self.region,
            dependency=self.dependency,
            client=client,
            session=session,
            node_definition=node_definition,
            id=self.id,
            provider=self.provider,
        )


class S3SinkComputeNode(ComputationNode):
    """
    Class representing an S3 Sink Computation node.
    """

    def __init__(
        self,
        id: str,
        name: str,
        dcr_id: str,
        credentials_dependency_id: str,
        endpoint: str,
        region: str,
        dependency: str,
        client: Client,
        session: Session,
        node_definition: NodeDefinition,
        provider: Optional[S3Provider] = S3Provider.AWS,
    ) -> None:
        """
        Initialise a `S3SinkComputeNode`:

        **Parameters**:
        - `id`: ID of the `S3SinkComputeNode`.
        - `name`: Name of the `S3SinkComputeNode`.
        - `dcr_id`: ID of the DCR the node is a member of.
        - `credentials_dependency_id`: ID of the `S3SinkComputeNode` dependency.
        - `endpoint`: Endpoint where data will be uploaded.
        - `region`: Region where the data will be uploaded.
        - `dependency`: Node that the `S3SinkComputeNode` depends on.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        - `node_definition`: Definition of the Raw Data Node.
        - `provider`: Type of S3 provider (AWS/GCS).
        """
        super().__init__(
            name=name,
            client=client,
            session=session,
            dcr_id=dcr_id,
            id=id,
            definition=node_definition,
        )
        self.credentials_dependency_id = credentials_dependency_id
        self.endpoint = endpoint
        self.region = region
        self.upload_dependency_id = dependency
        self.provider = provider
        self.specification_id = "decentriq.s3-sink-worker"

    def _get_computation_id(self) -> str:
        """
        Retrieve the ID of the node corresponding to the computation.
        """
        return self.id



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_source_snowflake.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64\x61ta_source_snowflake.proto\x12\x15\x64\x61ta_source_snowflake\"x\n\x0fSnowflakeSource\x12\x15\n\rwarehouseName\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61tabaseName\x18\x02 \x01(\t\x12\x12\n\nschemaName\x18\x03 \x01(\t\x12\x11\n\ttableName\x18\x04 \x01(\t\x12\x11\n\tstageName\x18\x05 \x01(\t\"\x7f\n&DataSourceSnowflakeWorkerConfiguration\x12\x36\n\x06source\x18\x01 \x01(\x0b\x32&.data_source_snowflake.SnowflakeSource\x12\x1d\n\x15\x63redentialsDependency\x18\x02 \x01(\tb\x06proto3')



_SNOWFLAKESOURCE = DESCRIPTOR.message_types_by_name['SnowflakeSource']
_DATASOURCESNOWFLAKEWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['DataSourceSnowflakeWorkerConfiguration']
SnowflakeSource = _reflection.GeneratedProtocolMessageType('SnowflakeSource', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKESOURCE,
  '__module__' : 'data_source_snowflake_pb2'
  # @@protoc_insertion_point(class_scope:data_source_snowflake.SnowflakeSource)
  })
_sym_db.RegisterMessage(SnowflakeSource)

DataSourceSnowflakeWorkerConfiguration = _reflection.GeneratedProtocolMessageType('DataSourceSnowflakeWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESNOWFLAKEWORKERCONFIGURATION,
  '__module__' : 'data_source_snowflake_pb2'
  # @@protoc_insertion_point(class_scope:data_source_snowflake.DataSourceSnowflakeWorkerConfiguration)
  })
_sym_db.RegisterMessage(DataSourceSnowflakeWorkerConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SNOWFLAKESOURCE._serialized_start=54
  _SNOWFLAKESOURCE._serialized_end=174
  _DATASOURCESNOWFLAKEWORKERCONFIGURATION._serialized_start=176
  _DATASOURCESNOWFLAKEWORKERCONFIGURATION._serialized_end=303
# @@protoc_insertion_point(module_scope)



from google.protobuf.json_format import MessageToDict
from ...proto import (
    serialize_length_delimited,
    ComputeNodeFormat,
    parse_length_delimited,
)
from ..node import Node
from .proto import (
    GoogleAdManagerWorkerConfiguration,
    SinkInput,
)
from typing import Literal


__docformat__ = "restructuredtext"
__pdoc__ = {
    "proto": False,
}

GoogleAdManagerIdentifierKind = Literal[
    "cookie_encrypted",
    "cookie_idfa",
    "ppid",
    "cookie_rida",
    "cookie_tvos",
    "cookie_adid",
]


class GoogleAdManager(Node):
    """
    Compute node that creates a Google Ad Manager segment list.
    """

    def __init__(
        self,
        name: str,
        input: SinkInput,
        credentialsDependency: str,
        identifier_kind: GoogleAdManagerIdentifierKind,
        list_id: str,
        input_has_headers: bool,
        bucket: str,
        object_name: str,
    ) -> None:
        config = GoogleAdManagerWorkerConfiguration(
            input=input,
            credentialsDependency=credentialsDependency,
            identifierKind=identifier_kind,
            listId=list_id,
            inputHasHeaders=input_has_headers,
            bucket=bucket,
            objectName=object_name,
        )
        config_serialized = serialize_length_delimited(config)
        dependencies = [input.dependency, credentialsDependency]
        super().__init__(
            name,
            config=config_serialized,
            enclave_type="decentriq.google-ad-manager-worker",
            dependencies=dependencies,
            output_format=ComputeNodeFormat.RAW,
        )


from ...decoder import GoogleAdManagerWorkerDecoder


__all__ = [
    "GoogleAdManager",
]
